@@ -5,6 +5,7 @@
 #include "sabundvector.hpp"
 #include "sharedrabundvector.hpp"
 #include "sequence.hpp"
+#include "protein.hpp"
 #include "mothurout.h"
 #include "utils.hpp"
 
@@ -23,7 +24,7 @@ public:
 	Calculator(){ m = MothurOut::getInstance(); needsAll = false; }
     Calculator(string n, int c, bool f) : name(n), cols(c), multiple(f) { m = MothurOut::getInstance(); needsAll = false; };
     Calculator(string n, int c, bool f, bool a) : name(n), cols(c), multiple(f), needsAll(a) { m = MothurOut::getInstance(); };
-	virtual ~Calculator(){};
+	virtual ~Calculator()=default;
 	
 	virtual EstOutput getValues(SAbundVector*) = 0;	
 	virtual EstOutput getValues(vector<SharedRAbundVector*>) = 0;
@@ -74,8 +75,6 @@ protected:
     MothurOut* m;
     Utils util;
     string name;
-    
-    
 };
 
 
@@ -84,10 +83,17 @@ protected:
 class DistCalc {
     
 public:
-    DistCalc(double c){ dist = 0; cutoff = c;  m = MothurOut::getInstance(); }
+    DistCalc(double c){ name = "unknown"; dist = 0; cutoff = c;  m = MothurOut::getInstance(); }
 
-    virtual ~DistCalc() {}
-    virtual double calcDist(Sequence, Sequence) = 0;
+    virtual ~DistCalc() = default;
+    virtual double calcDist(Sequence, Sequence) { return -1.0; }
+    virtual double calcDist(Protein, Protein)   { return -1.0; }
+    virtual string getCitation() = 0;
+    void citation() { m->mothurOut(getCitation()+"\n");}
+    
+    virtual string getName()        {    return name;        }
+    
+    //currently not used
     virtual vector<double> calcDist(Sequence A, classifierOTU otu, vector<int> cols) { vector<double> dists; dists.resize(otu.numSeqs, 1.0); return dists; }
     
 protected:
@@ -95,6 +101,7 @@ protected:
     MothurOut* m;
     Utils util;
     double cutoff;
+    string name;
     
     vector<int> setStartsIgnoreTermGap(classifierOTU seqA, classifierOTU otu, vector<int> cols);
     vector<int> setEndsIgnoreTermGap(classifierOTU seqA, classifierOTU otu, vector<int> cols);
@@ -107,8 +114,12 @@ protected:
     int setStartIgnoreTermGap(string, string, bool&);
     int setEndIgnoreTermGap(string, string, bool&);
     
+    //used by protein calcs
+    double makeDists(Protein, Protein, double eigs[20], double probs[20][20]);
+    void predict(vector<int> nb1, vector<int> nb2, double& p, double& dp, double& d2p, double& tt, double eigs[20], double probs[20][20]);
+    void fillNums(vector<int>& nb1, vector<int>& nb2, int, int);
+    
 };
-
 /**************************************************************************************************/
 
 
