@@ -9,23 +9,22 @@
 #ifndef erarefaction_hpp
 #define erarefaction_hpp
 
-#include "mothurout.h"
-#include "sabundvector.hpp"
+#include "diversitycalc.h"
 
 /***********************************************************************/
 
-class ERarefaction   {
+class ERarefaction : public DiversityCalculator   {
     
 public:
     
-    ERarefaction(){ m = MothurOut::getInstance(); }
-    double getValues(SAbundVector* rank, int n);
-    bool requiresSample() { return false; }
+    ERarefaction(int inc);
+    void getValues(SAbundVector* rank, vector<double>&);
     
+    string getTag() { return "e"; }
     
 private:
-    Utils util;
-    MothurOut* m;
+    
+    int increment;
 };
 
 /***********************************************************************/
