@@ -9,7 +9,7 @@
 #ifndef tn_hpp
 #define tn_hpp
 
-#include <calculator.h>
+#include "calculator.h"
 
 /***********************************************************************/
 
@@ -17,7 +17,7 @@ class TN : public ClusterMetric  {
     
 public:
     TN() : ClusterMetric("tn") {};
-    double getValue( long long tp,  long long tn,  long long fp,  long long fn);
+    double getValue(double tp,  double tn,  double fp,  double fn);
     string getCitation() { return "http://www.mothur.org/wiki/TN"; }
     
 private:
