@@ -20,20 +20,19 @@ class Weighted : public TreeCalculator  {
 	
 	public:
         Weighted( bool r, vector<string> G);
-		~Weighted() {};
+		~Weighted() = default;
 		
 		EstOutput getValues(Tree*, string, string);
-		EstOutput getValues(Tree*, int, string);
+		EstOutput getValues(Tree*, int);
 		
 	private:
         Utils util;
         int processors;
-        string outputDir;
         bool includeRoot;
         vector<string> Groups;
         vector< vector<string> > namesOfGroupCombos;
 		
-		EstOutput createProcesses(Tree*, CountTable*);
+		EstOutput createProcesses(Tree*);
 };
 /**************************************************************************************************/
 
