@@ -11,7 +11,7 @@
  
 #include "decalc.h"
 #include "mothurchimera.h"
-#include "database.hpp"
+#include "searchdatabase.hpp"
 
 /***********************************************************************/
 //This class was modeled after the chimeraMaligner written by the Broad Institute
@@ -21,7 +21,7 @@ class Maligner {
 	public:
 		
 		Maligner(vector<Sequence>, int, int, float, int, int); //int, int, int, , string, Database*, Database*
-		~Maligner() {};
+		~Maligner() = default;;
 		
 		string getResults(Sequence, DeCalculator);
 		float getPercentID() {	return percentIdenticalQueryChimera;	}
