@@ -14,6 +14,7 @@
 #include "mothurout.h"
 #include "groupmap.h"
 #include "counttable.h"
+#include "utils.hpp"
 
 /**************************************************************************************************/
 
@@ -36,7 +37,7 @@ public:
 	PhyloSummary(string, GroupMap*, bool, int);
     PhyloSummary(CountTable*, bool, int);
 	PhyloSummary(string, CountTable*, bool, int);
-	~PhyloSummary() {}
+	~PhyloSummary() = default;
 	
 	int summarize(string);  //pass it a taxonomy file and a group file and it makes the tree
 	int addSeqToTree(string, string);
@@ -46,7 +47,6 @@ public:
 	int getMaxLevel() { return maxLevel; }
 	
 private:
-	string getNextTaxon(string&);
 	vector<rawTaxNode> tree;
 	void print(int, ofstream&, string);
     void print(int, ofstream&, bool);
@@ -62,6 +62,7 @@ private:
 	int numSeqs;
 	int maxLevel;
 	MothurOut* m;
+    Utils util;
 };
 
 /**************************************************************************************************/
