@@ -34,7 +34,7 @@ ClusterClassic::ClusterClassic(float c, string f, bool s) : method(f),  nseqs(0)
 void ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 	try {
 		double distance;
-		bool square;
+		bool square = false;
 		string name;
 		vector<string> matrixNames;
 		
@@ -50,7 +50,7 @@ void ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 
 		matrixNames.push_back(name);
 
-		if(nameMap == NULL){
+		if(nameMap == nullptr){
 				list = new ListVector(nseqs);
 				list->set(0, name);
 		}
@@ -95,7 +95,7 @@ void ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 		
 
 						//there's A LOT of repeated code throughout this method...
-						if(nameMap == NULL){
+						if(nameMap == nullptr){
 								list->set(i, name);
 						
 								for(int j=0;j<i;j++){
@@ -152,7 +152,7 @@ void ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 						fileHandle >> name;                
 						matrixNames.push_back(name);
 						
-						if(nameMap == NULL){
+						if(nameMap == nullptr){
 								list->set(i, name);
 								for(int j=0;j<nseqs;j++){
 										fileHandle >> distance;
@@ -218,7 +218,7 @@ void ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 void ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
 	try {
 		double distance;
-		bool square;
+		bool square = false;
 		string name;
 		vector<string> matrixNames;
 		
@@ -234,7 +234,7 @@ void ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
         
 		matrixNames.push_back(name);
         
-		if(countTable == NULL){
+		if(countTable == nullptr){
             list = new ListVector(nseqs);
             list->set(0, name);
         }
@@ -281,7 +281,7 @@ void ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                 
                 
                 //there's A LOT of repeated code throughout this method...
-                 if(countTable == NULL){
+                 if(countTable == nullptr){
                     list->set(i, name);
                     
                     for(int j=0;j<i;j++){
@@ -333,7 +333,7 @@ void ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                 fileHandle >> name;                
                 matrixNames.push_back(name);
                 
-                if(countTable == NULL){
+                if(countTable == nullptr){
                     list->set(i, name);
                     for(int j=0;j<nseqs;j++){
                         fileHandle >> distance;
@@ -484,7 +484,7 @@ void ClusterClassic::update(double& cutOFF){
         				
 		for(int i=0;i<nseqs;i++){
 			if(i != r && i != c){
-				double distRow, distCol, newDist;
+                double distRow, distCol, newDist; newDist = 1.0;
 				if (i > r) { distRow = dMatrix[i][r]; }
 				else { distRow =  dMatrix[r][i]; }
 
