@@ -20,7 +20,7 @@
 #include "quitcommand.h"
 #include "helpcommand.h"
 #include "commandfactory.hpp"
-#include "deconvolutecommand.h"
+#include "uniqueseqscommand.h"
 #include "parsimonycommand.h"
 #include "unifracunweightedcommand.h"
 #include "unifracweightedcommand.h"
@@ -82,7 +82,7 @@
 #include "clusterfragmentscommand.h"
 #include "getlineagecommand.h"
 #include "removelineagecommand.h"
-#include "parsefastaqcommand.h"
+#include "fastaqinfocommand.h"
 #include "deuniqueseqscommand.h"
 #include "pairwiseseqscommand.h"
 #include "clusterdoturcommand.h"
@@ -154,6 +154,9 @@
 #include "diversityestimatorcommand.hpp"
 #include "srainfocommand.hpp"
 #include "makeclrcommand.hpp"
+#include "translateseqscommand.hpp"
+#include "alignmusclecommand.hpp"
+
 
 /*******************************************************/
 
@@ -172,7 +175,7 @@ CommandFactory::CommandFactory(){
 	m = MothurOut::getInstance();
     current = CurrentFile::getInstance();
 
-	current->setOutputDir(""); current->setInputDir("");
+	current->setOutputDir(""); current->setInputDir(nullVector);
 	append = false;
 
 	//initialize list of valid commands
@@ -221,6 +224,7 @@ CommandFactory::CommandFactory(){
 	commands["set.logfile"]			= "set.logfile";
 	commands["phylo.diversity"]		= "phylo.diversity";
 	commands["make.group"]			= "make.group";
+    commands["make.count"]          = "make.count";
 	commands["chop.seqs"]			= "chop.seqs";
 	commands["clearcut"]			= "clearcut";
 	commands["split.abund"]			= "split.abund";
@@ -324,6 +328,8 @@ CommandFactory::CommandFactory(){
     commands["estimator.single"]    = "estimator.single";
     commands["sra.info"]            = "sra.info";
     commands["make.clr"]            = "make.clr";
+    commands["tranlate.seqs"]       = "tranlate.seqs";
+    //commands["align.muscle"]        = "align.muscle";
 
 }
 
@@ -347,7 +353,7 @@ int CommandFactory::checkForRedirects(string optionString) {
                 if (foundEquals)       {   outputOption += optionString[i]; }
             }
             if (outputOption[0] == '=') { outputOption = outputOption.substr(1); }
-            outputOption = util.trimWhiteSpace(outputOption);
+            trimWhiteSpace(outputOption);
             outputOption = util.removeQuotes(outputOption);
             if(util.mkDir(outputOption)){
                 current->setOutputDir(outputOption);
@@ -365,11 +371,30 @@ int CommandFactory::checkForRedirects(string optionString) {
                 if (foundEquals)       {   intputOption += optionString[i]; }
             }
             if (intputOption[0] == '=') { intputOption = intputOption.substr(1); }
-            intputOption = util.trimWhiteSpace(intputOption);
+            trimWhiteSpace(intputOption);
             intputOption = util.removeQuotes(intputOption);
-            if(util.dirCheck(intputOption)){
-                current->setInputDir(intputOption); 
-                m->mothurOut("Setting input directory to: " + intputOption); m->mothurOutEndLine();
+    
+            vector<string> inputPaths;
+            vector<string> temp; util.splitAtChar(intputOption, temp, ';');
+            
+            for (int i = 0; i < temp.size(); i++) {
+                string inputPath = util.removeQuotes(temp[i]);
+                //add / to name if needed
+                string lastChar = inputPath.substr(inputPath.length()-1);
+                if (lastChar != PATH_SEPARATOR) { inputPath += PATH_SEPARATOR; }
+        
+                inputPath = util.getFullPathName(inputPath);
+                
+                if (util.dirCheckExists(inputPath)) { inputPaths.push_back(inputPath); }
+            }
+        
+            if (inputPaths.size() != 0) {
+                m->mothurOut("Setting input directories to: \n");
+                for (int i = 0; i < inputPaths.size(); i++) {
+                    m->mothurOut("\t" + inputPaths[i] + "\n");
+                }
+                m->mothurOutEndLine();
+                current->setInputDir(inputPaths);
             }
         }
 
@@ -385,7 +410,7 @@ int CommandFactory::checkForRedirects(string optionString) {
             if (intputOption[0] == '=') { intputOption = intputOption.substr(1); }
             bool seed = false; int random;
             if (intputOption == "clear") {
-                random = (int)time(NULL);
+                random = (int)time(nullptr);
                 seed = true;
             }else {
                 if (util.isNumeric1(intputOption)) { util.mothurConvert(intputOption, random); seed=true; }
@@ -414,12 +439,12 @@ int CommandFactory::checkForRedirects(string optionString) {
 Command* CommandFactory::getCommand(string commandName, string optionString){
 	try {
 
-        Command* command = NULL;
+        Command* command = nullptr;
         
-        if (commandName != "help") { checkForRedirects(optionString); }
+        if ((commandName != "help") && (commandName != "system")) { checkForRedirects(optionString); }
         
 		if(commandName == "cluster")                    {	command = new ClusterCommand(optionString);					}
-		else if(commandName == "unique.seqs")			{	command = new DeconvoluteCommand(optionString);				}
+		else if(commandName == "unique.seqs")			{	command = new UniqueSeqsCommand(optionString);				}
 		else if(commandName == "parsimony")				{	command = new ParsimonyCommand(optionString);				}
 		else if(commandName == "help")					{	command = new HelpCommand(optionString);					}
 		else if(commandName == "quit")					{	command = new QuitCommand(optionString);					}
@@ -478,7 +503,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 		else if(commandName == "set.dir")				{	command = new SetDirectoryCommand(optionString);			}
 		else if(commandName == "set.logfile")			{	command = new SetLogFileCommand(optionString);				}
 		else if(commandName == "phylo.diversity")		{	command = new PhyloDiversityCommand(optionString);			}
-		else if(commandName == "make.group")			{	command = new MakeGroupCommand(optionString);				}
+		else if((commandName == "make.group") || (commandName == "make.count"))			{	command = new MakeGroupCommand(optionString);				}
 		else if(commandName == "chop.seqs")				{	command = new ChopSeqsCommand(optionString);				}
 		else if(commandName == "clearcut")				{	command = new ClearcutCommand(optionString);				}
 		else if(commandName == "split.abund")			{	command = new SplitAbundCommand(optionString);				}
@@ -562,7 +587,9 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
         else if(commandName == "estimator.single")      {	command = new EstimatorSingleCommand(optionString);         }
         else if(commandName == "sra.info")              {   command = new SRAInfoCommand(optionString);                 }
         else if(commandName == "make.clr")              {   command = new MakeCLRCommand(optionString);                 }
-		else											{	command = new NoCommand(optionString);						}
+        else if(commandName == "translate.seqs")        {   command = new TranslateSeqsCommand(optionString);           }
+        //else if(commandName == "align.muscle")          {   command = new AlignMuscleCommand(optionString);             }
+        else											{	command = new NoCommand(optionString);						}
 
 		return command;
 	}
@@ -577,7 +604,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 //This function calls the appropriate command fucntions based on user input.
 Command* CommandFactory::getCommand(string commandName, string optionString, string mode){
 	try {
-		Command* pipecommand = NULL;   //delete the old command
+		Command* pipecommand = nullptr;   //delete the old command
         
         if (commandName != "help") {
             checkForRedirects(optionString);
@@ -589,13 +616,13 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
             }
             
             //user has opted to redirect input from dir where mothur.exe is located to some other place
-            if (current->getInputDir() != "") {
-                if (optionString != "") { optionString += ", inputdir=" + current->getInputDir(); }
-                else { optionString += "inputdir=" + current->getInputDir(); }
+            if ((current->getInputDir()).size() != 0) {
+                if (optionString != "") { optionString += ", inputdir=" + (current->getInputDir())[0]; }
+                else { optionString += "inputdir=" + (current->getInputDir())[0]; }
             }
         }
 		if(commandName == "cluster")				{	pipecommand = new ClusterCommand(optionString);					}
-		else if(commandName == "unique.seqs")			{	pipecommand = new DeconvoluteCommand(optionString);				}
+		else if(commandName == "unique.seqs")			{	pipecommand = new UniqueSeqsCommand(optionString);				}
 		else if(commandName == "parsimony")				{	pipecommand = new ParsimonyCommand(optionString);				}
 		else if(commandName == "help")					{	pipecommand = new HelpCommand(optionString);					}
 		else if(commandName == "quit")					{	pipecommand = new QuitCommand(optionString);					}
@@ -654,7 +681,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
 		else if(commandName == "set.dir")				{	pipecommand = new SetDirectoryCommand(optionString);			}
 		else if(commandName == "set.logfile")			{	pipecommand = new SetLogFileCommand(optionString);				}
 		else if(commandName == "phylo.diversity")		{	pipecommand = new PhyloDiversityCommand(optionString);			}
-		else if(commandName == "make.group")			{	pipecommand = new MakeGroupCommand(optionString);				}
+		else if((commandName == "make.group") || (commandName == "make.count"))			{	pipecommand = new MakeGroupCommand(optionString);				}
 		else if(commandName == "chop.seqs")				{	pipecommand = new ChopSeqsCommand(optionString);				}
 		else if(commandName == "clearcut")				{	pipecommand = new ClearcutCommand(optionString);				}
 		else if(commandName == "split.abund")			{	pipecommand = new SplitAbundCommand(optionString);				}
@@ -739,7 +766,10 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
         else if(commandName == "estimator.single")      {	pipecommand = new EstimatorSingleCommand(optionString);         }
         else if(commandName == "sra.info")              {   pipecommand = new SRAInfoCommand(optionString);                 }
         else if(commandName == "make.clr")              {   pipecommand = new MakeCLRCommand(optionString);                 }
-		else											{	pipecommand = new NoCommand(optionString);						}
+        else if(commandName == "translate.seqs")        {   pipecommand = new TranslateSeqsCommand(optionString);           }
+        //else if(commandName == "align.muscle")          {   pipecommand = new AlignMuscleCommand(optionString);             }
+
+        else											{	pipecommand = new NoCommand(optionString);						}
         
         
 
