@@ -21,7 +21,6 @@
 class ChimeraCheckCommand : public Command {
 public:
 	ChimeraCheckCommand(string);
-	ChimeraCheckCommand();
 	~ChimeraCheckCommand(){}
 	
 	vector<string> setParameters();
@@ -41,7 +40,7 @@ private:
 	int checkChimeras();
 
 	bool abort, svg, save;
-	string fastafile, templatefile, namefile, outputDir;
+	string fastafile, templatefile, namefile;
 	int increment, ksize, numSeqs, templateSeqsLength;
 	vector<string> outputNames;
 };
