@@ -30,7 +30,6 @@ class CollectCommand : public Command {
 	
 public:
 	CollectCommand(string);	
-	CollectCommand();
 	~CollectCommand(){}
 	
 	vector<string> setParameters();
@@ -47,9 +46,6 @@ public:
 	
 	
 private:
-	OrderVector* order;
-	InputData* input;
-	Collect* cCurve;
 	vector<Display*> cDisplays;
 	int abund, size, alpha;
 	float freq;
@@ -57,12 +53,13 @@ private:
 
 	bool abort, allLines;
 	set<string> labels; //holds labels to be used
-	string label, calc, outputDir, sharedfile, listfile, rabundfile, sabundfile, format, inputfile;
+	string label, calc, sharedfile, listfile, rabundfile, sabundfile, format, inputfile;
 	vector<string>  Estimators;
 	vector<string> inputFileNames;
     
 	
 	vector<string> parseSharedFile(string);
+    void fillCDisplays(map<string, string>);
 
 
 };
