@@ -71,7 +71,7 @@ string CountGroupsCommand::getHelpString(){
 	}
 }
 //**********************************************************************************************************************
-CountGroupsCommand::CountGroupsCommand(string option)  {
+CountGroupsCommand::CountGroupsCommand(string option) : Command()  {
 	try {
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
