@@ -17,7 +17,6 @@ class CountGroupsCommand : public Command {
 public:
 	
 	CountGroupsCommand(string);
-	CountGroupsCommand();	
 	~CountGroupsCommand(){}
 	
 	vector<string> setParameters();
@@ -33,7 +32,7 @@ public:
 	
 	
 private:
-	string sharedfile, groupfile, countfile, outputDir, groups, accnosfile;
+	string sharedfile, groupfile, countfile,  groups, accnosfile;
 	bool abort;
 	vector<string> Groups;
     vector<string> outputNames;
