@@ -70,7 +70,7 @@ string DeUniqueSeqsCommand::getOutputPattern(string type) {
     }
 }
 /**************************************************************************************/
-DeUniqueSeqsCommand::DeUniqueSeqsCommand(string option)  {	
+DeUniqueSeqsCommand::DeUniqueSeqsCommand(string option) : Command()  {	
 	try {
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -158,14 +158,13 @@ int DeUniqueSeqsCommand::execute() {
         
 		if (m->getControl_pressed()) {  out.close(); outputTypes.clear(); util.mothurRemove(outFastaFile); if (countfile != "") { if (ct.hasGroupInfo()) { outGroup.close(); util.mothurRemove(outGroupFile); } } return 0; }
 		
-		ifstream in;
-		util.openInputFile(fastaFile, in);
+		ifstream in; util.openInputFile(fastaFile, in);
 		
 		while (!in.eof()) {
 		
 			if (m->getControl_pressed()) { in.close(); out.close(); outputTypes.clear(); util.mothurRemove(outFastaFile); if (countfile != "") { if (ct.hasGroupInfo()) { outGroup.close(); util.mothurRemove(outGroupFile); } } return 0; }
 			
-			Sequence seq(in); util.gobble(in);
+			Sequence seq(in); gobble(in);
 			
 			if (seq.getName() != "") {
 				
