@@ -36,14 +36,13 @@ struct repStruct {
 		
 		repStruct(){}
 		repStruct(string n, string seq, string b, int sb, int s, string g) : name(n), bin(b), size(s), group(g), simpleBin(sb), sequence(seq) { }
-		~repStruct() {}
+		~repStruct() = default;
 };
 
 class GetOTURepCommand : public Command {
 
 public:
 	GetOTURepCommand(string);
-	GetOTURepCommand();
 	~GetOTURepCommand(){}
 	
 	vector<string> setParameters();
@@ -61,30 +60,28 @@ public:
 	
 	
 private:
-	ListVector* list;
-	GroupMap* groupMap;
+	
     map<string, int> nameMap;
     OptiData* matrix;
     CountTable ct;
-	string filename, fastafile, listfile, namefile, groupfile, label, sorted, phylipfile, countfile, columnfile, distFile, format, outputDir, groups, method;
+	string filename, fastafile, listfile, namefile, groupfile, sorted, phylipfile, countfile, columnfile, distFile, format,  groups, method;
 	ofstream out;
 	ifstream in, inNames, inRow;
-	bool abort, allLines, groupError, weighted, hasGroups, rename;
-	set<string> labels; //holds labels to be used
-	//map<string, string> nameFileMap;
+	bool abort, allLines, groupError, weighted, hasGroups, rename, cutoffSet;
 	vector<string> outputNames, Groups;
 	map<string, string> outputNameFiles;
-	float cutoff;
+	set<string> cutoffs;
+    float cutoff;
 	int precision;
     
-	void readNamesFile(FastaMap*&);
-	//void readNamesFile(bool);
-	int process(ListVector*);
+	void readNamesFile(FastaMap&);
+    int process(ListVector*, GroupMap&);
 	string findRep(vector<string>, map<string, long long>&, string); 	// returns the name of the "representative" sequence of given bin or subset of a bin, for groups
     string findRepAbund(vector<string>, string);
 	int processNames(string, string);
-	int processFastaNames(string, string, FastaMap*&);
+	int processFastaNames(string, string, FastaMap&, GroupMap&);
     int readDist();
+    void createCount();
 };
 
 #endif
