@@ -19,7 +19,6 @@
 class GetRAbundCommand : public Command {
 public:
 	GetRAbundCommand(string);
-	GetRAbundCommand();
 	~GetRAbundCommand(){}
 	
 	vector<string> setParameters();
@@ -38,7 +37,7 @@ public:
 	
 private:
 	
-	string filename, listfile, sabundfile, inputfile, format, outputDir, countfile, sharedfile;
+	string filename, listfile, sabundfile, inputfile, format,  countfile, sharedfile;
 	ofstream out;
 	vector<string> outputNames, Groups;
 
