@@ -17,7 +17,6 @@ class GetRelAbundCommand : public Command {
 
 public:
 	GetRelAbundCommand(string);
-	GetRelAbundCommand();
 	~GetRelAbundCommand(){}
 	
 	vector<string> setParameters();
@@ -38,7 +37,7 @@ private:
 	
 	bool abort, allLines, pickedGroups;
 	set<string> labels; //holds labels to be used
-	string groups, label, outputDir, scale, sharedfile;
+	string groups, label,  scale, sharedfile;
 	vector<string> Groups, outputNames;
 	
 	int getRelAbundance(SharedRAbundVectors*&, ofstream&);
