@@ -87,7 +87,7 @@ string GetSharedOTUCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-GetSharedOTUCommand::GetSharedOTUCommand(string option)  {
+GetSharedOTUCommand::GetSharedOTUCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -247,7 +247,7 @@ int GetSharedOTUCommand::execute(){
                 while(!inFasta.eof()) {
                     if (m->getControl_pressed()) { outputTypes.clear(); inFasta.close(); delete groupMap; return 0; }
                     
-                    Sequence seq(inFasta); util.gobble(inFasta);
+                    Sequence seq(inFasta); gobble(inFasta);
                     if (seq.getName() != "") {  seqs.push_back(seq);   }
                 }
                 inFasta.close();
@@ -260,7 +260,7 @@ int GetSharedOTUCommand::execute(){
             
             ListVector* list = util.getNextList(input, allLines, userLabels, processedLabels, lastLabel);
             
-            while (list != NULL) {
+            while (list != nullptr) {
                 
                 if (m->getControl_pressed()) { delete list; break; }
                 
@@ -411,7 +411,7 @@ int GetSharedOTUCommand::process(ListVector* shared) {
 			outputString += groupString + ".";
 			m->mothurOut(outputString); m->mothurOutEndLine();
 		}else { 
-			m->mothurOut("\t" + toString(num)); m->mothurOutEndLine(); 
+            m->mothurOut(shared->getLabel() + "\t" + toString(num)+"\n");
 			outputNames.push_back(outputFileNames);
 			if (output != "accnos") { outputTypes["sharedseqs"].push_back(outputFileNames); }
 			else { outputTypes["accnos"].push_back(outputFileNames); }
@@ -457,13 +457,14 @@ int GetSharedOTUCommand::process(ListVector* shared) {
 /***********************************************************/
 int GetSharedOTUCommand::runShared() {
 	try {
-        InputData input(sharedfile, "sharedfile", Groups);
+        InputData input(sharedfile, "sharedfile", nullVector);
 		set<string> processedLabels;
         set<string> userLabels = labels;
         string lastLabel = "";
         
         SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
-        Groups = lookup->getNamesGroups();
+        
+        if (Groups.size() == 0) { Groups = lookup->getNamesGroups(); }
         
         if (userGroups == "") {
             //make string for outputfile name
@@ -476,7 +477,7 @@ int GetSharedOTUCommand::runShared() {
         //put groups in map to find easier
         for(int i = 0; i < Groups.size(); i++) { groupFinder[Groups[i]] = Groups[i];}
         
-        while (lookup != NULL) {
+        while (lookup != nullptr) {
             
             if (m->getControl_pressed()) { delete lookup; break; }
             
@@ -509,8 +510,7 @@ int GetSharedOTUCommand::process(SharedRAbundVectors*& lookup) {
 		if (output != "accnos") { outputFileNames = getOutputFileName("sharedseqs", variables); }
 		else { outputFileNames = getOutputFileName("accnos", variables); }
         
-        ofstream outNames;
-		util.openOutputFile(outputFileNames, outNames);
+        ofstream outNames; util.openOutputFile(outputFileNames, outNames);
 		
 		bool wroteSomething = false;
 		int num = 0;
@@ -577,7 +577,7 @@ int GetSharedOTUCommand::process(SharedRAbundVectors*& lookup) {
 			outputString += groupString + ".";
 			m->mothurOut(outputString); m->mothurOutEndLine();
 		}else {
-			m->mothurOut("\t" + toString(num)); m->mothurOutEndLine();
+			m->mothurOut(lookup->getLabel() + "\t" + toString(num)+"\n");
 			outputNames.push_back(outputFileNames);
 			if (output != "accnos") { outputTypes["sharedseqs"].push_back(outputFileNames); }
 			else { outputTypes["accnos"].push_back(outputFileNames); }
