@@ -20,22 +20,23 @@
 
 //**********************************************************************************************************************
 struct sharedIndexes {
-    int groupIndex;
-    int otuIndex;
+    int treatmentIndex;
+    int sampleIndex;
+    
+    sharedIndexes() : treatmentIndex(0), sampleIndex(0) {}
+    sharedIndexes(int g, int o) : treatmentIndex(g), sampleIndex(o) {}
     
-    sharedIndexes() : groupIndex(0), otuIndex(0) {}
-    sharedIndexes(int g, int o) : groupIndex(g), otuIndex(o) {}
     
     bool operator<(const sharedIndexes& rhs) const {
-        return rhs.groupIndex < this->groupIndex || (rhs.groupIndex == this->groupIndex && rhs.otuIndex < this->otuIndex);
+        return rhs.treatmentIndex < this->treatmentIndex || (rhs.treatmentIndex == this->treatmentIndex && rhs.sampleIndex < this->sampleIndex);
     }
     
     bool operator>(const sharedIndexes& rhs) const {
-        return rhs.groupIndex > this->groupIndex || (rhs.groupIndex == this->groupIndex && rhs.otuIndex > this->otuIndex);
+        return rhs.treatmentIndex > this->treatmentIndex || (rhs.treatmentIndex == this->treatmentIndex && rhs.sampleIndex > this->sampleIndex);
     }
     
     bool operator=(const sharedIndexes& rhs) const {
-        return ((rhs.groupIndex == this->groupIndex) && (rhs.otuIndex == this->otuIndex));
+        return ((rhs.treatmentIndex == this->treatmentIndex) && (rhs.sampleIndex == this->sampleIndex));
     }
 };
 //**********************************************************************************************************************
@@ -43,7 +44,6 @@ struct sharedIndexes {
 class IndicatorCommand : public Command {
 public:
 	IndicatorCommand(string);
-	IndicatorCommand();
 	~IndicatorCommand(){}
 	
 	vector<string> setParameters();
@@ -60,14 +60,14 @@ public:
 	
 private:
 	DesignMap* designMap;
-	string treefile, sharedfile, relabundfile, groups, label, inputFileName, outputDir, designfile;
+	string treefile, sharedfile, relabundfile, groups, label, inputFileName,  designfile;
     bool abort;
     int iters, processors;
     vector<string> outputNames, Groups, namesSeqs;
     	
 	set<string> getDescendantList(Tree*&, int, map<int, set<string> >, map<int, set<int> >&);
 	map<int, float> getDistToRoot(Tree*&);
-	vector< map<sharedIndexes, sharedIndexes> > randomizeGroupings(vector<int>, int);
+	vector< map<sharedIndexes, vector<int> > > randomizeGroupings(vector<int>, int);
     
     SharedRAbundVectors* getShared();
     SharedRAbundFloatVectors* getSharedFloat();
