@@ -87,7 +87,7 @@ string LibShuffCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-LibShuffCommand::LibShuffCommand(string option)  {
+LibShuffCommand::LibShuffCommand(string option) : Command()  {
 	try {
 
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -170,8 +170,7 @@ int LibShuffCommand::execute(){
 		int error = groupMap->readMap();
 		if (error == 1) { delete groupMap; return 0; }
 		
-		ifstream in;
-		util.openInputFile(phylipfile, in);
+		ifstream in; util.openInputFile(phylipfile, in);
 		matrix = new FullMatrix(in, groupMap, sim); //reads the matrix file
 		in.close();
 		
