@@ -18,6 +18,7 @@ vector<string> ListSeqsCommand::setParameters(){
 	try {
         CommandParameter pfastq("fastq", "InputTypes", "", "", "FNGLT", "FNGLT", "none","accnos",false,false,true); parameters.push_back(pfastq);
 		CommandParameter pfasta("fasta", "InputTypes", "", "", "FNGLT", "FNGLT", "none","accnos",false,false,true); parameters.push_back(pfasta);
+        CommandParameter pqfile("qfile", "InputTypes", "", "", "FNGLT", "FNGLT", "none","accnos",false,false,true); parameters.push_back(pqfile);
 		CommandParameter pname("name", "InputTypes", "", "", "FNGLT", "FNGLT", "none","accnos",false,false,true); parameters.push_back(pname);
         CommandParameter pcount("count", "InputTypes", "", "", "FNGLT", "FNGLT", "none","accnos",false,false,true); parameters.push_back(pcount);
 		CommandParameter pgroup("group", "InputTypes", "", "", "FNGLT", "FNGLT", "none","accnos",false,false,true); parameters.push_back(pgroup);
@@ -47,7 +48,7 @@ vector<string> ListSeqsCommand::setParameters(){
 string ListSeqsCommand::getHelpString(){	
 	try {
 		string helpString = "";
-		helpString += "The list.seqs command reads a fasta, name, group, count, list, taxonomy, fastq, alignreport or contigsreport file and outputs a .accnos file containing sequence names.\n";
+		helpString += "The list.seqs command reads a fasta, name, group, count, list, taxonomy, fastq, qfile, alignreport or contigsreport file and outputs a .accnos file containing sequence names.\n";
 		helpString += "The list.seqs command parameters are fasta, name, group, count, list, taxonomy, fastq, contigsreport and alignreport.  You must provide one of these parameters.\n";
 		helpString += "The list.seqs command should be in the following format: list.seqs(fasta=yourFasta).\n";
 		helpString += "Example list.seqs(fasta=amazon.fasta).\n";
@@ -75,7 +76,7 @@ string ListSeqsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-ListSeqsCommand::ListSeqsCommand(string option)  {
+ListSeqsCommand::ListSeqsCommand(string option) : Command()  {
 	try {
 
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -86,9 +87,6 @@ ListSeqsCommand::ListSeqsCommand(string option)  {
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			
-			
-			//check for required parameters
 			fastafiles = validParameter.validFiles(parameters, "fasta");
             if (fastafiles.size() != 0) {
                 if (fastafiles[0] == "not open") { abort = true; }
@@ -115,6 +113,7 @@ ListSeqsCommand::ListSeqsCommand(string option)  {
             contigsreportfiles = validParameter.validFiles(parameters, "contigsreport");
             if (contigsreportfiles.size() != 0) {
                 if (contigsreportfiles[0] == "not open") { abort = true; }
+                else { current->setContigsReportFile(contigsreportfiles[0]); }
             }
 			
 			listfiles = validParameter.validFiles(parameters, "list");
@@ -140,7 +139,13 @@ ListSeqsCommand::ListSeqsCommand(string option)  {
                 if (fastqfiles[0] == "not open") { abort = true; }
             }
 			
-			if ((fastqfiles.size() == 0) && (countfiles.size() == 0) && (fastafiles.size() == 0) && (namefiles.size() == 0) && (listfiles.size() == 0) && (groupfiles.size() == 0) && (alignfiles.size() == 0) && (taxfiles.size() == 0) && (contigsreportfiles.size() == 0))  { m->mothurOut("You must provide a file.\n"); abort = true; }
+            qualityfiles = validParameter.validFiles(parameters, "qfile");
+            if (qualityfiles.size() != 0) {
+                if (qualityfiles[0] == "not open") { abort = true; }
+                else { current->setQualFile(qualityfiles[0]); }
+            }
+            
+			if ((qualityfiles.size() == 0) && (fastqfiles.size() == 0) && (countfiles.size() == 0) && (fastafiles.size() == 0) && (namefiles.size() == 0) && (listfiles.size() == 0) && (groupfiles.size() == 0) && (alignfiles.size() == 0) && (taxfiles.size() == 0) && (contigsreportfiles.size() == 0))  { m->mothurOut("You must provide a file.\n"); abort = true; }
 		}
 	}
 	catch(exception& e) {
@@ -149,16 +154,43 @@ ListSeqsCommand::ListSeqsCommand(string option)  {
 	}
 }
 //**********************************************************************************************************************
-void addName(bool empty, string name, set<string>& names, set<string>& newNames) {
+void addName(bool empty, string name, unordered_set<string>& names, unordered_set<string>& newNames) {
     if (empty) { newNames.insert(name); } //for first file or single file
     else {
         if (names.count(name) != 0) { newNames.insert(name); } //present in files so far so add to newNames
     }
 }
+#ifdef USE_BOOST
 //**********************************************************************************************************************
-void readFastq(set<string>& names, ifstream& in, MothurOut*& m){
+void readFastq(unordered_set<string>& names, boost::iostreams::filtering_istream& inBoost, MothurOut*& m){
     try {
-        set<string> newNames;
+        unordered_set<string> newNames;
+        bool empty = true;
+        if (names.size() != 0) { empty=false; }
+        Utils util;
+        
+        while(!inBoost.eof()){
+            
+            if (m->getControl_pressed()) { break; }
+            
+            bool ignore;
+            FastqRead fread(inBoost, ignore, "illumina1.8+");  gobble(inBoost);
+            
+            if (!ignore) { addName(empty, fread.getName(), names, newNames); }
+        }
+        
+        names = newNames;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "ListSeqsCommand", "readFastq");
+        exit(1);
+    }
+}
+#endif
+//**********************************************************************************************************************
+void readFastq(unordered_set<string>& names, ifstream& in, MothurOut*& m){
+    try {
+        unordered_set<string> newNames;
         bool empty = true;
         if (names.size() != 0) { empty=false; }
         Utils util;
@@ -168,7 +200,7 @@ void readFastq(set<string>& names, ifstream& in, MothurOut*& m){
             if (m->getControl_pressed()) { break; }
             
             bool ignore;
-            FastqRead fread(in, ignore, "illumina1.8+"); util.gobble(in);
+            FastqRead fread(in, ignore, "illumina1.8+"); gobble(in);
             
             if (!ignore) { addName(empty, fread.getName(), names, newNames); }
         }
@@ -181,9 +213,9 @@ void readFastq(set<string>& names, ifstream& in, MothurOut*& m){
     }
 }
 //**********************************************************************************************************************
-void readFasta(set<string>& names, ifstream& in, MothurOut*& m){
+void readQual(unordered_set<string>& names, ifstream& in, MothurOut*& m){
     try {
-        set<string> newNames;
+        unordered_set<string> newNames;
         bool empty = true;
         if (names.size() != 0) { empty=false; }
         Utils util;
@@ -192,7 +224,31 @@ void readFasta(set<string>& names, ifstream& in, MothurOut*& m){
             
             if (m->getControl_pressed()) { break; }
             
-            Sequence currSeq(in); util.gobble(in);
+            QualityScores currSeq(in); gobble(in);
+            
+            if (currSeq.getName() != "") { addName(empty, currSeq.getName(), names, newNames); }
+        }
+        
+        names = newNames;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "ListSeqsCommand", "readQual");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
+void readFasta(unordered_set<string>& names, ifstream& in, MothurOut*& m){
+    try {
+        unordered_set<string> newNames;
+        bool empty = true;
+        if (names.size() != 0) { empty=false; }
+        Utils util;
+        
+        while(!in.eof()){
+            
+            if (m->getControl_pressed()) { break; }
+            
+            Sequence currSeq(in); gobble(in);
             
             if (currSeq.getName() != "") { addName(empty, currSeq.getName(), names, newNames); }
         }
@@ -205,9 +261,9 @@ void readFasta(set<string>& names, ifstream& in, MothurOut*& m){
     }
 }
 //**********************************************************************************************************************
-void readList(set<string>& names, ifstream& in, MothurOut*& m){
+void readList(unordered_set<string>& names, ifstream& in, MothurOut*& m){
     try {
-        set<string> newNames;
+        unordered_set<string> newNames;
         bool empty = true;
         if (names.size() != 0) { empty=false; }
         
@@ -235,9 +291,9 @@ void readList(set<string>& names, ifstream& in, MothurOut*& m){
     }
 }
 //**********************************************************************************************************************
-void readNameTaxGroup(set<string>& names, ifstream& in, MothurOut*& m){
+void readNameTaxGroup(unordered_set<string>& names, ifstream& in, MothurOut*& m){
     try {
-        set<string> newNames;
+        unordered_set<string> newNames;
         bool empty = true;
         if (names.size() != 0) { empty=false; }
 
@@ -247,7 +303,7 @@ void readNameTaxGroup(set<string>& names, ifstream& in, MothurOut*& m){
         
             if (m->getControl_pressed()) { break; }
 
-            in >> name; util.getline(in); util.gobble(in);
+            in >> name; util.getline(in); gobble(in);
             
             addName(empty, name, names, newNames);
         }
@@ -260,9 +316,9 @@ void readNameTaxGroup(set<string>& names, ifstream& in, MothurOut*& m){
     }
 }
 //**********************************************************************************************************************
-void readCount(set<string>& names, ifstream& in, MothurOut*& m){
+void readCount(unordered_set<string>& names, ifstream& in, MothurOut*& m){
     try {
-        set<string> newNames;
+        unordered_set<string> newNames;
         bool empty = true;
         if (names.size() != 0) { empty=false; }
         
@@ -282,19 +338,19 @@ void readCount(set<string>& names, ifstream& in, MothurOut*& m){
     }
 }
 //**********************************************************************************************************************
-void readAlignContigs(set<string>& names, ifstream& in, MothurOut*& m){
+void readAlignContigs(unordered_set<string>& names, ifstream& in, MothurOut*& m){
     try {
-        set<string> newNames;
+        unordered_set<string> newNames;
         bool empty = true;
         if (names.size() != 0) { empty=false; }
         string name;
         
-        Utils util; util.getline(in);  util.gobble(in);
+        Utils util; util.getline(in);  gobble(in);
         
         while(!in.eof()){
             if (m->getControl_pressed()) { break; }
 
-            in >> name; util.getline(in); util.gobble(in);
+            in >> name; util.getline(in); gobble(in);
             
             addName(empty, name, names, newNames);
         }
@@ -313,18 +369,19 @@ int ListSeqsCommand::execute(){
 		
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
-        set<string> names;
+        unordered_set<string> names;
         
 		//read functions fill names vector
-		if (fastafiles.size() != 0)		    {   process(fastafiles, names, &readFasta);	        }
-        if (fastqfiles.size() != 0)	        {	process(fastqfiles, names, &readFastq);	        }
-		if (namefiles.size() != 0)	        {	process(namefiles, names, &readNameTaxGroup);   }
-		if (groupfiles.size() != 0)	        {	process(groupfiles, names, &readNameTaxGroup);  }
-        if (taxfiles.size() != 0)           {   process(taxfiles, names, &readNameTaxGroup);    }
-		if (alignfiles.size() != 0)	        {   process(alignfiles, names, &readAlignContigs);         }
-        if (contigsreportfiles.size() != 0) {   process(contigsreportfiles, names, &readAlignContigs); }
-		if (listfiles.size() != 0)	        {	process(listfiles, names, &readList);       }
-        if (countfiles.size() != 0)	        {	process(countfiles, names, &readCount);     }
+		if (fastafiles.size() != 0)		    {   process(fastafiles, names, &readFasta);	                }
+        if (qualityfiles.size() != 0)       {   process(qualityfiles, names, &readQual);                }
+        if (fastqfiles.size() != 0)	        {	process(fastqfiles, names);	                            }
+		if (namefiles.size() != 0)	        {	process(namefiles, names, &readNameTaxGroup);           }
+		if (groupfiles.size() != 0)	        {	process(groupfiles, names, &readNameTaxGroup);          }
+        if (taxfiles.size() != 0)           {   process(taxfiles, names, &readNameTaxGroup);            }
+		if (alignfiles.size() != 0)	        {   process(alignfiles, names, &readAlignContigs);          }
+        if (contigsreportfiles.size() != 0) {   process(contigsreportfiles, names, &readAlignContigs);  }
+		if (listfiles.size() != 0)	        {	process(listfiles, names, &readList);                   }
+        if (countfiles.size() != 0)	        {	process(countfiles, names, &readCount);                 }
         
 		if (m->getControl_pressed()) { outputTypes.clear();  return 0; }
 		
@@ -358,7 +415,38 @@ int ListSeqsCommand::execute(){
 	}
 }
 //**********************************************************************************************************************
-void ListSeqsCommand::process(vector<string> files, set<string>& names, void f(set<string>&, ifstream&, MothurOut*&)){
+void ListSeqsCommand::process(vector<string> files, unordered_set<string>& names){
+    try {
+        Utils util;
+        
+        for (int i = 0; i < files.size(); i++) {
+            if (m->getControl_pressed()) { break; }
+            
+            inputFileName = files[i];
+            
+            bool gz = util.isGZ(inputFileName)[1];
+            
+            if (!gz) {
+                ifstream in; util.openInputFile(inputFileName, in);
+                readFastq(names, in, m);
+                in.close();
+            }else {
+                #ifdef USE_BOOST
+                    ifstream in; boost::iostreams::filtering_istream inBoost;
+                    util.openInputFileBinary(inputFileName, in, inBoost);
+                    readFastq(names, inBoost, m);
+                    in.close(); inBoost.pop(); inBoost.reset();
+                #endif
+            }
+        }
+    }
+    catch(exception& e) {
+        m->errorOut(e, "ListSeqsCommand", "process");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
+void ListSeqsCommand::process(vector<string> files, unordered_set<string>& names, void f(unordered_set<string>&, ifstream&, MothurOut*&)){
     try {
         Utils util;
         for (int i = 0; i < files.size(); i++) {
