@@ -15,7 +15,6 @@ class MakeFileCommand : public Command {
     
 public:
     MakeFileCommand(string);
-    MakeFileCommand();
     ~MakeFileCommand(){}
     
     vector<string> setParameters();
@@ -32,7 +31,7 @@ public:
 
 private:
     
-    string inputDir, outputDir, typeFile, prefix, delim;
+    string inputDir,  typeFile, prefix, delim;
     vector<string> outputNames;
     int numCols;
     bool abort;
