@@ -9,6 +9,7 @@
 
 #include "makegroupcommand.h"
 #include "sequence.hpp"
+#include "counttable.h"
 
 
 //**********************************************************************************************************************
@@ -17,7 +18,8 @@ vector<string> MakeGroupCommand::setParameters(){
 		CommandParameter pfasta("fasta", "InputTypes", "", "", "none", "none", "none","group",false,true,true); parameters.push_back(pfasta);
 		CommandParameter pgroups("groups", "String", "", "", "", "", "","",false,false,true); parameters.push_back(pgroups);
 		CommandParameter poutput("output", "String", "", "", "", "", "","",false,false); parameters.push_back(poutput);
-		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
+        CommandParameter pformat("format", "Multiple", "count-group", "count", "", "", "","",false,false,true); parameters.push_back(pformat);
+        CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
 		
@@ -25,6 +27,7 @@ vector<string> MakeGroupCommand::setParameters(){
         
         vector<string> tempOutNames;
         outputTypes["group"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
         
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -39,9 +42,10 @@ vector<string> MakeGroupCommand::setParameters(){
 string MakeGroupCommand::getHelpString(){	
 	try {
 		string helpString = "";
-		helpString += "The make.group command reads a fasta file or series of fasta files and creates a groupfile.\n";
-		helpString += "The make.group command parameters are fasta, groups and output. Fasta and group are required.\n";
-		helpString += "The output parameter allows you to specify the name of groupfile created. \n";
+		helpString += "The make.group (also called make.count) command reads a fasta file or series of fasta files and creates a group file or count file.\n";
+		helpString += "The make.group command parameters are fasta, groups, format and output. Fasta and groups are required.\n";
+		helpString += "The output parameter allows you to specify the name of group file or count file created. \n";
+        helpString += "The format parameter allows you to specify whether the outputtted file is a group file or count file. Default=count. \n";
 		helpString += "The make.group command should be in the following format: \n";
 		helpString += "make.group(fasta=yourFastaFiles, groups=yourGroups). \n";
 		helpString += "Example make.group(fasta=seqs1.fasta-seq2.fasta-seqs3.fasta, groups=A-B-C)\n";
@@ -57,7 +61,8 @@ string MakeGroupCommand::getOutputPattern(string type) {
     try {
         string pattern = "";
         
-        if (type == "group") {  pattern = "[filename],groups"; } 
+        if (type == "group") {  pattern = "[filename],groups"; }
+        else if (type == "count") {  pattern = "[filename],count_table"; }
         else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
@@ -68,7 +73,7 @@ string MakeGroupCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-MakeGroupCommand::MakeGroupCommand(string option)  {
+MakeGroupCommand::MakeGroupCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -80,32 +85,25 @@ MakeGroupCommand::MakeGroupCommand(string option)  {
 			
 			ValidParameters validParameter;
             
-            
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
+			string inputDir = validParameter.validPath(parameters, "inputdir");
 			if (inputDir == "not found"){	inputDir = "";		}
 
             fastaFileNames = validParameter.validFiles(parameters, "fasta");
             if (fastaFileNames.size() != 0) {
                 if (fastaFileNames[0] == "not open") { abort = true; }
-                else {
-                    current->setFastaFile(fastaFileNames[0]);
-                    filename = util.getRootName(util.getSimpleName(fastaFileNames[0]));
-                    //prevent giantic file name
-                    map<string, string> variables;
-                    variables["[filename]"] = filename;
-                    if (fastaFileNames.size() > 3) { variables["[filename]"] = "merge."; }
-                    filename = getOutputFileName("group",variables);
-                }
+                else {  current->setFastaFile(fastaFileNames[0]); }
             }
             
             //make sure there is at least one valid file left
             if (fastaFileNames.size() == 0) { m->mothurOut("[ERROR]: no valid files.\n");  abort = true; }
             
-			output = validParameter.valid(parameters, "output");			
+			output = validParameter.validPath(parameters, "output");
 			if (output == "not found") { output = "";  }
-			else{ filename = output; }
 			
+            format = validParameter.valid(parameters, "format");        if (format == "not found"){    format = "count";    }
+            if ((format != "count") && (format != "group")) { m->mothurOut("\n[WARNING]: invalid format option: choices are count or group, using count.\n");  format="count"; }
+            
 			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { m->mothurOut("groups is a required parameter for the make.group command.\n");  abort = true;  }
 			else { util.splitAtDash(groups, groupsNames);	}
@@ -123,44 +121,76 @@ MakeGroupCommand::MakeGroupCommand(string option)  {
 int MakeGroupCommand::execute(){
 	try {
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
+        
+        util.checkGroupNames(groupsNames);
 		
-		if (outputdir == "") { outputdir = util.hasPath(fastaFileNames[0]); }
-			
-		filename = outputdir + filename;
-		
-		ofstream out;
-		util.openOutputFile(filename, out);
-		
+        map<string, string> seqGroup; map<string, long long> groupCounts;
 		for (int i = 0; i < fastaFileNames.size(); i++) {
+            
+            if (m->getControl_pressed()) { break; }
+            
+            m->mothurOutJustToScreen("\nAssigning sequences from file " + fastaFileNames[i] + " to group " +  groupsNames[i] + ":\t");
 		
-			if (m->getControl_pressed()) { outputTypes.clear(); out.close(); util.mothurRemove(filename); return 0; }
-			
-			ifstream in;
-			util.openInputFile(fastaFileNames[i], in);
+			ifstream in; util.openInputFile(fastaFileNames[i], in);
 			
+            long long count = 0;
 			while (!in.eof()) {
 				
-				Sequence seq(in); util.gobble(in);
-				
-				if (m->getControl_pressed()) { outputTypes.clear();  in.close(); out.close(); util.mothurRemove(filename); return 0; }
-				
-				if (seq.getName() != "") {	out << seq.getName() << '\t' << groupsNames[i] << endl;		}
+                if (m->getControl_pressed()) { break; }
+                
+				Sequence seq(in); gobble(in);
+								
+                if (seq.getName() != "") {	seqGroup[seq.getName()] = groupsNames[i];	count++;	}
 			}
 			in.close();
+            m->mothurOutJustToScreen(toString(count) + " sequences assigned to group " +  groupsNames[i] + "\n");
+            groupCounts[groupsNames[i]] = count;
 		}
-		
-		out.close();
-		
-		
-		m->mothurOut("\nOutput File Names: " + filename + "\n\n");
-        outputNames.push_back(filename); outputTypes["group"].push_back(filename);
-		
+        
+        if (m->getControl_pressed()) { return 0; }
+        
+        //if user provided output filename, then use it
+        string outputFileName = util.getFullPathName(output);
+        
+        //if no output filename given, create one
+        if (output == "") {
+            map<string, string> variables;
+            if (outputdir == "") { outputdir = util.hasPath(fastaFileNames[0]); }
+            variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastaFileNames[0]));
+            if (fastaFileNames.size() > 1) { variables["[filename]"] = outputdir + "merge."; }
+            outputFileName = getOutputFileName(format,variables);
+        }
+        outputNames.push_back(outputFileName); outputTypes[format].push_back(outputFileName);
+        
+        if (format == "count") {
+            CountTable ct; ct.createTable(seqGroup);
+            ct.printCompressedTable(outputFileName);
+        }else{
+            ofstream out; util.openOutputFile(outputFileName, out);
+            for (map<string, string>::iterator it = seqGroup.begin(); it != seqGroup.end(); it++) {
+                out << it->first << '\t' << it->second << endl;
+            }
+            out.close();
+        }
+        
+        long long total = 0;
+        if (groupCounts.size() != 0) {  m->mothurOut("\nGroup count: \n");  }
+        for (map<string, long long>::iterator it = groupCounts.begin(); it != groupCounts.end(); it++) { total += it->second; m->mothurOut(it->first + "\t" + toString(it->second) + "\n"); }
+        if (total != 0) { m->mothurOut("\nTotal of all groups is " + toString(total) + "\n"); }
+
+		m->mothurOut("\nOutput File Names: " + outputFileName + "\n\n");
+        
 		//set group file as new current groupfile
 		string currentName = "";
 		itTypes = outputTypes.find("group");
 		if (itTypes != outputTypes.end()) {
 			if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setGroupFile(currentName); }
 		}
+        
+        itTypes = outputTypes.find("count");
+        if (itTypes != outputTypes.end()) {
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setCountFile(currentName); }
+        }
 		
 		return 0;
 	}
