@@ -20,7 +20,6 @@
 class MakeLefseCommand : public Command {
 public:
     MakeLefseCommand(string);
-    MakeLefseCommand();
     ~MakeLefseCommand(){}
     
     vector<string> setParameters();
@@ -37,7 +36,6 @@ public:
     
 private:
     bool abort, allLines, otulabel, hasGroupInfo;
-    string outputDir;
     vector<string> outputNames, Groups;
     string sharedfile, designfile, constaxonomyfile, relabundfile, scale, label, inputFile;
     
