@@ -19,8 +19,7 @@ class MergeCountCommand : public Command {
     
 public:
     MergeCountCommand(string);
-    MergeCountCommand();
-    ~MergeCountCommand() {}
+    ~MergeCountCommand() = default;
     
     vector<string> setParameters();
     string getCommandName()			{ return "merge.count";	}
@@ -38,7 +37,7 @@ public:
 private:
     
     bool abort;
-    string outputDir, inputDir, countfile, output, outputFileName;
+    string  inputDir, countfile, output, outputFileName;
     vector<string> outputNames, fileNames;
     int numInputFiles;
     
