@@ -79,7 +79,7 @@ string NMDSCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-NMDSCommand::NMDSCommand(string option)  {
+NMDSCommand::NMDSCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -463,10 +463,9 @@ int NMDSCommand::output(vector< vector<double> >& config, vector<string>& names,
 /*****************************************************************/
 vector< vector<double> > NMDSCommand::readAxes(vector<string> names){
 	try {
-		ifstream in;
-		util.openInputFile(axesfile, in);
+		ifstream in; util.openInputFile(axesfile, in);
 		
-		string headerLine = util.getline(in); util.gobble(in);
+		string headerLine = util.getline(in); gobble(in);
 		
 		//count the number of axis you are reading
 		bool done = false;
@@ -496,7 +495,7 @@ vector< vector<double> > NMDSCommand::readAxes(vector<string> names){
 			if (m->getControl_pressed()) { in.close(); return axes; }
 			
 			string group = "";
-			in >> group; util.gobble(in);
+			in >> group; gobble(in);
 			
 			bool ignore = false;
 			if (!util.inUsersGroups(group, names)) { ignore = true; m->mothurOut(group + " is in your axes file and not in your distance file, ignoring.\n");  }
@@ -512,7 +511,7 @@ vector< vector<double> > NMDSCommand::readAxes(vector<string> names){
 			
 			if (!ignore) {	orderedAxes[group] = thisGroupsAxes; }
 			
-			util.gobble(in);
+			gobble(in);
 		}
 		in.close();
 				
