@@ -11,7 +11,7 @@
 
 //**********************************************************************************************************************
 
-NoCommand::NoCommand(string option)  {}
+NoCommand::NoCommand(string option) : Command()  {}
 
 //**********************************************************************************************************************
 
