@@ -76,7 +76,7 @@ string ParsimonyCommand::getOutputPattern(string type) {
     }
 }
 /***********************************************************/
-ParsimonyCommand::ParsimonyCommand(string option)  {
+ParsimonyCommand::ParsimonyCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -125,7 +125,6 @@ ParsimonyCommand::ParsimonyCommand(string option)  {
                 if ((groupfile != "") && (countfile != "")) {
                     m->mothurOut("[ERROR]: you may only use one of the following: group or count.\n");  abort=true;
                 }
-
 			}
 			
 			if (outputdir == ""){  	if (randomtree == "")  { outputdir += util.hasPath(treefile); } }
@@ -145,13 +144,6 @@ ParsimonyCommand::ParsimonyCommand(string option)  {
 			string temp = validParameter.valid(parameters, "processors");	if (temp == "not found"){	temp = current->getProcessors();	}
 			processors = current->setProcessors(temp);
 						
-			if (countfile=="") {
-                if (namefile == "") {
-                    vector<string> files; files.push_back(treefile);
-                    if (!current->getMothurCalling())  {  parser.getNameFile(files);   }
-                } 
-            }
-			
 		}
 
 	}
