@@ -9,7 +9,7 @@
 
 #include "splitgroupscommand.h"
 #include "preclustercommand.h"
-#include "deconvolutecommand.h"
+#include "uniqueseqscommand.h"
 #include "summary.hpp"
 
 //**********************************************************************************************************************
@@ -21,7 +21,7 @@ vector<string> PreClusterCommand::setParameters(){
         CommandParameter pgroup("group", "InputTypes", "", "", "CountGroup", "none", "none","",false,false,true); parameters.push_back(pgroup);
         CommandParameter pdiffs("diffs", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pdiffs);
         CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
-        CommandParameter palign("align", "Multiple", "needleman-gotoh-blast-noalign", "needleman", "", "", "","",false,false); parameters.push_back(palign);
+        CommandParameter palign("align", "Multiple", "needleman-gotoh-noalign", "needleman", "", "", "","",false,false); parameters.push_back(palign);
         CommandParameter pmatch("match", "Number", "", "1.0", "", "", "","",false,false); parameters.push_back(pmatch);
         CommandParameter pmismatch("mismatch", "Number", "", "-1.0", "", "", "","",false,false); parameters.push_back(pmismatch);
         CommandParameter pgapopen("gapopen", "Number", "", "-2.0", "", "", "","",false,false); parameters.push_back(pgapopen);
@@ -29,7 +29,7 @@ vector<string> PreClusterCommand::setParameters(){
         CommandParameter palpha("alpha", "Number", "", "2.0", "", "", "","",false,false); parameters.push_back(palpha);
         CommandParameter pdelta("delta", "Number", "", "2.0", "", "", "","",false,false); parameters.push_back(pdelta);
         CommandParameter pmethod("method", "Multiple", "simple-unoise-tree-deblur", "simple", "", "", "","",false,false); parameters.push_back(pmethod);
-        
+        CommandParameter pclump("clump", "Multiple", "lessthan-lessthanequal", "lessthan", "", "", "","",false,false); parameters.push_back(pclump);
         CommandParameter perror_rate("error_rate", "Number", "", "0.005", "", "", "","",false,false); parameters.push_back(perror_rate);
         CommandParameter pindel_prob("indel_prob", "Number", "", "0.01", "", "", "","",false,false); parameters.push_back(pindel_prob);
         CommandParameter pmax_indels("max_indels", "Number", "", "3", "", "", "","",false,false); parameters.push_back(pmax_indels);
@@ -67,7 +67,8 @@ string PreClusterCommand::getHelpString(){
     helpString += "The count parameter allows you to provide a count file so you can cluster by group. \n";
 		helpString += "The diffs parameter allows you to specify maximum number of mismatched bases allowed between sequences in a grouping. The default is 1.\n";
     helpString += "The method parameter allows you to specify the algorithm to use to complete the preclusterign step. Possible methods include simple, tree, unoise, and deblur.  Default=simple.\n";
-    helpString += "The align parameter allows you to specify the alignment align_method to use.  Your options are: gotoh, needleman, blast and noalign. The default is needleman.\n";
+    helpString += "The clump parameter allows you to specify which reads can be combined. Possible options include lessthan and lessthanequal. lessthan -> merge reads with less abundance. lessthanequal -> merge reads with less than or equal abundance Default=lessthan.\n";
+    helpString += "The align parameter allows you to specify the alignment align_method to use.  Your options are: gotoh, needleman and noalign. The default is needleman.\n";
     helpString += "The match parameter allows you to specify the bonus for having the same base. The default is 1.0.\n";
     helpString += "The mistmatch parameter allows you to specify the penalty for having different bases.  The default is -1.0.\n";
     helpString += "The gapopen parameter allows you to specify the penalty for opening a gap in an alignment. The default is -2.0.\n";
@@ -109,7 +110,7 @@ string PreClusterCommand::getOutputPattern(string type) {
     }
 }
 //**************************************************************************************************
-PreClusterCommand::PreClusterCommand(string option) {
+PreClusterCommand::PreClusterCommand(string option) : Command() {
 	try {
 
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -134,12 +135,12 @@ PreClusterCommand::PreClusterCommand(string option) {
 
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			string namefile = validParameter.validFile(parameters, "name");
+			namefile = validParameter.validFile(parameters, "name");
 			if (namefile == "not found") { namefile =  "";  }
 			else if (namefile == "not open") { namefile = ""; abort = true; }
 			else {  current->setNameFile(namefile); }
 
-			string groupfile = validParameter.validFile(parameters, "group");
+			groupfile = validParameter.validFile(parameters, "group");
 			if (groupfile == "not found") { groupfile =  "";  bygroup = false; }
 			else if (groupfile == "not open") { abort = true; groupfile =  ""; }
 			else {   current->setGroupFile(groupfile); bygroup = true;  }
@@ -168,6 +169,15 @@ PreClusterCommand::PreClusterCommand(string option) {
             temp = validParameter.valid(parameters, "method"); if(temp == "not found"){  temp = "simple"; }
             pc_method = temp;
             
+            if ((pc_method == "simple") || (pc_method == "tree") || (pc_method == "unoise") || (pc_method == "deblur")) { }
+            else { m->mothurOut("[ERROR]: Not a valid precluster method.  Valid preclustering algorithms include simple, tree, unoise, and deblur. Using simple.\n");  pc_method= "simple"; }
+            
+            temp = validParameter.valid(parameters, "clump"); if(temp == "not found"){  temp = "lessthan"; }
+            clump = temp;
+            
+            if ((clump == "lessthan") || (clump == "lessthanequal")) { }
+            else { m->mothurOut("[ERROR]: Not a valid clump method.  Valid clumping options are lessthan and lessthanequal. Using lessthan.\n");  clump = "lessthan"; }
+            
             temp = validParameter.valid(parameters, "match"); if(temp == "not found"){	temp = "1.0";			}
             util.mothurConvert(temp, match);
             
@@ -204,7 +214,6 @@ PreClusterCommand::PreClusterCommand(string option) {
                 }
             }
  
-            
             temp = validParameter.valid(parameters, "error_rate");	if (temp == "not found"){	temp = "0.005";			}
             util.mothurConvert(temp, error_rate);
             if (error_rate < 0) { m->mothurOut("[ERROR]: error_rate must be positive.\n"); abort=true; }
@@ -219,20 +228,7 @@ PreClusterCommand::PreClusterCommand(string option) {
             util.mothurConvert(temp, max_indels);
             if (indel_prob < 0) { m->mothurOut("[ERROR]: max_indels must be positive.\n"); abort=true; }
             
-            
-            
             align = validParameter.valid(parameters, "align");		if (align == "not found"){	align = "needleman";	}
-            if (align == "blast") {
-                string blastlocation = "";
-                vector<string> locations = current->getLocations();
-                string path = current->getProgramPath();
-                bool foundTool = util.findBlastLocation(blastlocation, path, locations);
-
-                if (!foundTool){
-                    m->mothurOut("[WARNING]: Unable to locate blast executables, cannot use blast as align method. Using needleman instead.\n"); align = "needleman";
-                }
-            }
-            
             align_method = "unaligned";
             
             if (!abort) {
@@ -251,75 +247,7 @@ PreClusterCommand::PreClusterCommand(string option) {
                     countfile = outputFileName;
                 }
             }
-            
-            if (countfile == "") {
-                if (namefile == "") {
-                    vector<string> files; files.push_back(fastafile);
-                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-                }
-            }
-            
-            
-            if(pc_method == "tree"){
-                
-                diffs = 1;
-                
-            } else {
-                
-                Summary summary_data(processors);
-                if(countfile != ""){
-                    summary_data.summarizeFasta(fastafile, countfile, "");
-                } else if(namefile != ""){
-                    summary_data.summarizeFasta(fastafile, namefile, "");
-                }
-                int median_length = summary_data.getLength()[3];
-                int max_abund = summary_data.getMaxAbundance();
-                
-                
-                if(pc_method == "unoise"){
-                    
-                    diffs = int((log2(max_abund)-1) / alpha + 1);
-                    
-                } else if(pc_method == "deblur"){
-                    
-                    if(util.isEqual(error_dist[0], -100)){ //construct the binomial distribution
-                        
-                        error_dist.clear();
-                        
-                        for(int i=0;i<100;i++){
-                            
-                            double choose = 1;
-                            double k = 1;
-                            
-                            for(int j=1;j<=i;j++){
-                                choose *= (median_length - j + 1);
-                                k *= j;
-                            }
-                            choose = choose/k;
-                            
-                            double a = pow(error_rate, i);
-                            double b = pow(1 - error_rate, median_length - i);
-                            
-                            if(!util.isEqual(a, 0) && !util.isEqual(b, 0)){
-                                error_dist.push_back(choose * a * b);
-                                if(error_dist[i] < 0.1 / max_abund){ break;	}
-                            } else {
-                                break;
-                            }
-                        }
-                        error_dist[0] = 1;
-                    }
-                    
-                    double mod_factor = pow((1-error_rate), median_length);
-                    
-                    for(int i=0;i<error_dist.size();i++){
-                        error_dist[i] /= (double)mod_factor;
-                    }
-                    diffs = error_dist.size();
-                }
-            }
         }
-        
     }
     catch(exception& e) {
         m->errorOut(e, "PreClusterCommand", "PreClusterCommand");
@@ -328,17 +256,16 @@ PreClusterCommand::PreClusterCommand(string option) {
 }
 /************************************************************/
 
-inline bool comparePriorityTopDown(seqPNode* first, seqPNode* second) {
+inline bool comparePriorityAbundance(seqPNode* first, seqPNode* second) {
   if (first->numIdentical > second->numIdentical){
  		return true;
 	}
   return false;
 }
-
 //**************************************************************************************************
 
 struct preClusterData {
-  string fastafile, countfile, pc_method, align_method, align, newMName;
+  string fastafile, countfile, pc_method, align_method, align, newMName, clump;
   OutputWriter* newNName;
   MothurOut* m;
   int start, end, count, diffs, length, numGroups;
@@ -357,14 +284,15 @@ struct preClusterData {
 				// double indel_prob = 0.01;indel_prob
 				// double max_indels = 3;max_indels
 
-  ~preClusterData() { if (alignment != NULL) { delete alignment; } }
+  ~preClusterData() { if (alignment != nullptr) { delete alignment; } }
 
   preClusterData(){}
 
-  preClusterData(map<string, vector<string> > g2f, string f, string c, string pcm, string am,  OutputWriter* nnf, string nmf, vector<string> gr) {
+  preClusterData(map<string, vector<string> > g2f, string f, string c, string pcm, string am,  string cl, OutputWriter* nnf, string nmf, vector<string> gr) {
     fastafile = f;
     pc_method = pcm;
     align_method = am;
+    clump = cl;
     newNName = nnf;
     newMName = nmf;
     groups = gr;
@@ -397,14 +325,13 @@ struct preClusterData {
     if (align_method == "unaligned") {
       if(align == "gotoh")	{	alignment = new GotohOverlap(gapOpen, gapExtend, match, misMatch, 1000);	}
       else if(align == "needleman")	{	alignment = new NeedlemanOverlap(gapOpen, match, misMatch, 1000);			}
-      else if(align == "blast")		{	alignment = new BlastAlignment(gapOpen, gapExtend, match, misMatch);		}
       else if(align == "noalign")		{	alignment = new NoAlign();													}
       else {
           m->mothurOut(align + " is not a valid alignment option. I will run the command using needleman.");
           m->mothurOutEndLine();
           alignment = new NeedlemanOverlap(gapOpen, match, misMatch, 1000);
       }
-    } else { alignment = NULL; }
+    } else { alignment = nullptr; }
   }
 };
 
@@ -515,7 +442,7 @@ void mergeSeqs(seqPNode* representative, seqPNode* duplicate, string& chunk, int
         }
         representative->numIdentical += duplicate->numIdentical;
         
-        chunk += representative->name + "\t" + duplicate->name + "\t" + toString(originalCount) + "\t" + toString(mismatch) + "\t" + duplicate->sequence + "\n";
+        chunk += (representative->name + "\t" + duplicate->name + "\t" + toString(originalCount) + "\t" + toString(mismatch) + "\t" + duplicate->sequence + "\n");
         duplicate->numIdentical = 0;
         duplicate->diffs = mismatch;
     }
@@ -546,6 +473,8 @@ int process(string group, string newMapFile, preClusterData* params){
         
         for (int i = 0; i < numSeqs; i++) { originalCount[i] = params->alignSeqs[i]->numIdentical; }
         
+        bool lessThan = true;
+        if (params->clump == "lessthanequal") { lessThan = false; }
         
         if(params->pc_method == "simple"){
             for (int i = 0; i < numSeqs; i++) {
@@ -559,7 +488,13 @@ int process(string group, string newMapFile, preClusterData* params){
                         
                         if (params->m->getControl_pressed()) { out.close(); return 0; }
                         
-                        if ((params->alignSeqs[j]->numIdentical != 0) && (originalCount[j] < originalCount[i])) {  //this sequence has not been merged yet //
+                        bool ableToMerge = false;
+                        if (lessThan) { //default
+                            if (originalCount[j] < originalCount[i]) { ableToMerge = true; }
+                        }else { //less than equal to
+                            if (originalCount[j] <= originalCount[i]) { ableToMerge = true; }
+                        }
+                        if ((params->alignSeqs[j]->numIdentical != 0) && (ableToMerge)) {  //this sequence has not been merged yet //
                             //are you within "diff" bases
                             int mismatch = calcMisMatches(params->alignSeqs[i]->sequence, params->alignSeqs[j]->sequence, params);
                             
@@ -568,19 +503,18 @@ int process(string group, string newMapFile, preClusterData* params){
                     }
                     out << chunk;
                 }
-                if(i % 100 == 0)	{ params->m->mothurOutJustToScreen(group + toString(i) + "\t" + toString(numSeqs - count) + "\t" + toString(count)+"\n"); }
+                if(i % 1000 == 0)	{ params->m->mothurOutJustToScreen(group + toString(i) + "\t" + toString(numSeqs - count) + "\t" + toString(count)+"\n"); }
             }
             
-            if(numSeqs % 100 != 0)	{ params->m->mothurOut(group + toString(numSeqs) + "\t" + toString(numSeqs - count) + "\t" + toString(count) + "\n"); 	}
+            if(numSeqs % 1000 != 0)	{ params->m->mothurOut(group + toString(numSeqs) + "\t" + toString(numSeqs - count) + "\t" + toString(count) + "\n"); 	}
             
         } else if(params->pc_method == "unoise") {
             
-            vector<double> beta(params->diffs, 0);
+            vector<double> beta(params->diffs+1, 0);
             for(int i=0;i<beta.size();i++){
                 beta[i] = pow(0.5, params->alpha * i + 1.0);
             }
             
-            
             for (int i = 0; i < numSeqs; i++) {
                 
                 if (params->alignSeqs[i]->numIdentical != 0) {  //this sequence has not been merged yet
@@ -592,13 +526,17 @@ int process(string group, string newMapFile, preClusterData* params){
                         
                         if (params->m->getControl_pressed()) { out.close(); return 0; }
                         
-                        if (params->alignSeqs[j]->numIdentical != 0 && originalCount[j] < originalCount[i]) {  //this sequence has not been merged yet
+                        if (params->alignSeqs[j]->numIdentical != 0 && (originalCount[j] < originalCount[i])) {  //this sequence has not been merged yet
                             
                             double skew = (double)originalCount[j]/(double)originalCount[i];
                             
                             int mismatch = calcMisMatches(params->alignSeqs[i]->sequence, params->alignSeqs[j]->sequence, params);
                         
-                            if (mismatch <= params->diffs && skew <= beta[mismatch]) { mergeSeqs(params->alignSeqs[i], params->alignSeqs[j], chunk, mismatch, originalCount[j], params); count++; }
+                            if (mismatch <= params->diffs) {
+                                if (skew <= beta[mismatch]) {
+                                    mergeSeqs(params->alignSeqs[i], params->alignSeqs[j], chunk, mismatch, originalCount[j], params); count++;
+                                }
+                            }
                         }
                     }
                     out << chunk;
@@ -724,15 +662,9 @@ int process(string group, string newMapFile, preClusterData* params){
                 }
             }
             
-        } else {
-            
-            cout << "fail!\n";
-            
-        }
+        } else { cout << "fail!\n"; }
         
-        if(params->pc_method != "deblur"){
-            out.close();
-        }
+        if(params->pc_method != "deblur"){ out.close(); }
         
         return count;
   }
@@ -741,7 +673,6 @@ int process(string group, string newMapFile, preClusterData* params){
       exit(1);
   }
 }
-
 /**************************************************************************************************/
 
 void filterSeqs(vector<seqPNode*>& alignSeqs, int length, MothurOut* m){
@@ -790,7 +721,7 @@ vector<seqPNode*> readFASTA(preClusterData* params, long long& num){
 
             if (params->m->getControl_pressed()) { inFasta.close(); break; }
 
-            Sequence seq(inFasta);  params->util.gobble(inFasta);
+            Sequence seq(inFasta);  gobble(inFasta);
 
             if (seq.getName() != "") {  //can get "" if commented line is at end of fasta file
 
@@ -812,7 +743,7 @@ vector<seqPNode*> readFASTA(preClusterData* params, long long& num){
         else if (lengths.size() == 1) {  params->align_method = "aligned"; filterSeqs(alignSeqs, params->length, params->m); }
 
         //sort seqs by number of identical seqs
-        sort(alignSeqs.begin(), alignSeqs.end(), comparePriorityTopDown);
+        sort(alignSeqs.begin(), alignSeqs.end(), comparePriorityAbundance);
         num = alignSeqs.size();
 
         return alignSeqs;
@@ -827,41 +758,26 @@ vector<seqPNode*> readFASTA(preClusterData* params, long long& num){
 
 void print(string newfasta, string newname, preClusterData* params){
     try {
-        ofstream outAccnos;
-        string outAccnosFileName = newfasta + ".temp";
-        params->util.openOutputFile(outAccnosFileName, outAccnos);
-        
-        CountTable ct;
+        CountTable ct; unordered_set<string> accnosNames;
         if (params->countfile != "") {
             for (int i = 0; i < params->alignSeqs.size(); i++) {
                 if (params->alignSeqs[i]->numIdentical != 0) {
-                    outAccnos << params->alignSeqs[i]->name << endl;
                     ct.push_back(params->alignSeqs[i]->name, params->alignSeqs[i]->numIdentical);
                 }
             }
         }
-        outAccnos.close();
         
         if (params->countfile != "")  { ct.printTable(newname); }
 
-        //use unique.seqs to create new name and fastafile
-        string inputString = "fasta=" + params->fastafile + ", accnos=" + outAccnosFileName;
         params->m->mothurOut("/******************************************/\n");
-        params->m->mothurOut("Running command: get.seqs(" + inputString + ")\n");
+        pair<string, string> ffiles(params->fastafile, newfasta);
         
-        GetSeqsCommand* getCommand = new GetSeqsCommand(inputString);
+        Command* getCommand = new GetSeqsCommand(accnosNames, ffiles, nullStringPair, nullStringPair, "");
         getCommand->execute();
-        
-        map<string, vector<string> > filenames = getCommand->getOutputFiles();
-        
+                
         delete getCommand;
-        
-        params->util.renameFile(filenames["fasta"][0], newfasta);
-        
+                
         params->m->mothurOut("/******************************************/\nDone.\n");
-        
-        params->util.mothurRemove(outAccnosFileName);
-
     }
     catch(exception& e) {
         params->m->errorOut(e, "PreClusterCommand", "print");
@@ -875,7 +791,63 @@ int PreClusterCommand::execute(){
         
         if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
-        long start = time(NULL);
+        if(pc_method == "tree"){
+            diffs = 1;
+        }else if (pc_method == "simple") { ;
+        } else {
+            Summary summary_data(processors);
+            if(countfile != ""){
+                summary_data.summarizeFasta(fastafile, countfile, "");
+            } else if(namefile != ""){
+                summary_data.summarizeFasta(fastafile, namefile, "");
+            }
+            int median_length = summary_data.getLength()[3];
+            int max_abund = summary_data.getMaxAbundance();
+            
+            if(pc_method == "unoise"){
+                
+                diffs = int((log2(max_abund)-1) / alpha + 1);
+                
+            } else if(pc_method == "deblur"){
+                
+                if(util.isEqual(error_dist[0], -100)){ //construct the binomial distribution
+                    
+                    error_dist.clear();
+                    
+                    for(int i=0;i<100;i++){
+                        
+                        double choose = 1;
+                        double k = 1;
+                        
+                        for(int j=1;j<=i;j++){
+                            choose *= (median_length - j + 1);
+                            k *= j;
+                        }
+                        choose = choose/k;
+                        
+                        double a = pow(error_rate, i);
+                        double b = pow(1 - error_rate, median_length - i);
+                        
+                        if(!util.isEqual(a, 0) && !util.isEqual(b, 0)){
+                            error_dist.push_back(choose * a * b);
+                            if(error_dist[i] < 0.1 / max_abund){ break;    }
+                        } else {
+                            break;
+                        }
+                    }
+                    error_dist[0] = 1;
+                }
+                
+                double mod_factor = pow((1-error_rate), median_length);
+                
+                for(int i=0;i<error_dist.size();i++){
+                    error_dist[i] /= (double)mod_factor;
+                }
+                diffs = error_dist.size();
+            }
+        }
+        
+        long start = time(nullptr);
         
         string numProcessors = current->getProcessors();
         
@@ -906,28 +878,28 @@ int PreClusterCommand::execute(){
             current->setMothurCalling(true);
             SequenceCountParser cparser(countfile, fastafile, nullVector);
             current->setMothurCalling(false);
-            cout << " groups = "<< cparser.getNamesOfGroups().size() << endl;
+            //cout << " groups = "<< cparser.getNamesOfGroups().size() << endl;
             groups = cparser.getNamesOfGroups();
             group2Files = cparser.getFiles();
             
             createProcessesGroups(group2Files, groups, convolutedNamesFile, newMapFile);
             
-            string accnosFile;
-            if (countfile != "") {  accnosFile = mergeGroupCounts(newCountFile, convolutedNamesFile); }
+            unordered_set<string> accnos;
+            if (countfile != "") {  accnos = mergeGroupCounts(newCountFile, convolutedNamesFile); }
             
-            printFasta(newFastaFile, accnosFile);
+            printFasta(newFastaFile, accnos);
             util.mothurRemove(convolutedNamesFile);
             
             if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}	 return 0; }
             
-            m->mothurOut("It took " + toString(time(NULL) - start) + " secs to run pre.cluster.\n");
+            m->mothurOut("It took " + toString(time(nullptr) - start) + " secs to run pre.cluster.\n");
             
         }else {
             if (processors != 1) { m->mothurOut("When using running without group information mothur can only use 1 processor, continuing.\n");  processors = 1; }
             
             vector<string> groups;
             map<string, vector<string> > group2Files;
-            preClusterData* params = new preClusterData(group2Files, fastafile, countfile, pc_method, align_method, NULL, newMapFile, nullVector);
+            preClusterData* params = new preClusterData(group2Files, fastafile, countfile, pc_method, align_method, clump, nullptr, newMapFile, nullVector);
             params->setVariables(diffs, pc_method, align_method, align, match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels, error_dist);
             
             //reads fasta file and return number of seqs
@@ -951,7 +923,7 @@ int PreClusterCommand::execute(){
             
             print(newFastaFile, newCountFile, params);
             for (int i = 0; i < params->alignSeqs.size(); i++) {  delete params->alignSeqs[i]; } params->alignSeqs.clear();
-            m->mothurOut("It took " + toString(time(NULL) - start) + " secs to cluster " + toString(numSeqs) + " sequences.\n");
+            m->mothurOut("It took " + toString(time(nullptr) - start) + " secs to cluster " + toString(numSeqs) + " sequences.\n");
         }
         
         current->setProcessors(numProcessors);
@@ -989,26 +961,17 @@ int PreClusterCommand::execute(){
 }
 /**************************************************************************************************/
 
-void PreClusterCommand::printFasta(string newFastaFileName, string accnosFile){
+void PreClusterCommand::printFasta(string newFastaFileName, unordered_set<string> accnos){
     try {
-        
-        //run unique.seqs for deconvolute results
-        string inputString = "fasta=" + fastafile + ", accnos=" + accnosFile;
+        pair<string, string> ffiles(fastafile, newFastaFileName);
         
         m->mothurOut("\n/******************************************/\n");
-        m->mothurOut("Running command: get.seqs(" + inputString + ")\n");
-        current->setMothurCalling(true);
-        
-        Command* getCommand = new GetSeqsCommand(inputString);
-        getCommand->execute();
-        
-        map<string, vector<string> > filenames = getCommand->getOutputFiles();
+        m->mothurOut("Running get.seqs: \n");
         
+        Command* getCommand = new GetSeqsCommand(accnos, ffiles, nullStringPair, nullStringPair, "");
         delete getCommand;
-        current->setMothurCalling(false);
+                
         m->mothurOut("/******************************************/\n");
-        
-        util.renameFile(filenames["fasta"][0], newFastaFileName);
     }
     catch(exception& e) {
         m->errorOut(e, "PreClusterCommand", "printFasta");
@@ -1081,14 +1044,13 @@ bool fillWeighted(preClusterData* params, string fastafileName, string groupOrCo
             params->util.mothurRemove(groupOrCountFile);
         }
         
-        ifstream in;
-        params->util.openInputFile(fastafileName, in);
+        ifstream in; params->util.openInputFile(fastafileName, in);
         
         while (!in.eof()) {
             
             if (params->m->getControl_pressed()) { break; }
             
-            Sequence seq(in); params->util.gobble(in);
+            Sequence seq(in); gobble(in);
             
             if (seq.getName() != "") {
                 
@@ -1131,7 +1093,7 @@ long long driverGroups(preClusterData* params){
             string thisGroup = it->first;
             params->m->mothurOut("\nProcessing group " + thisGroup + ":\n");
             
-            time_t start = time(NULL);
+            time_t start = time(nullptr);
             bool aligned = false;
             
             string thisGroupsFasta = it->second[0];
@@ -1147,7 +1109,7 @@ long long driverGroups(preClusterData* params){
             params->util.mothurRemove(thisGroupsFasta);
             
             //sort seqs by number of identical seqs
-            sort(params->alignSeqs.begin(), params->alignSeqs.end(), comparePriorityTopDown);
+            sort(params->alignSeqs.begin(), params->alignSeqs.end(), comparePriorityAbundance);
             
             long long num = params->alignSeqs.size();
             numSeqs += num;
@@ -1179,7 +1141,7 @@ long long driverGroups(preClusterData* params){
             
             for (int i = 0; i < params->alignSeqs.size(); i++) {  delete params->alignSeqs[i]; } params->alignSeqs.clear();
             
-            params->m->mothurOut("It took " + toString(time(NULL) - start) + " secs to cluster " + toString(num) + " sequences.\n");
+            params->m->mothurOut("It took " + toString(time(nullptr) - start) + " secs to cluster " + toString(num) + " sequences.\n");
         }
         
         return numSeqs;
@@ -1192,7 +1154,7 @@ long long driverGroups(preClusterData* params){
 
 /**************************************************************************************************/
 //only called with count table including groups
-string PreClusterCommand::mergeGroupCounts(string newcount, string newname){
+unordered_set<string> PreClusterCommand::mergeGroupCounts(string newcount, string newname){
 	try {
         m->mothurOut("\nDeconvoluting count table results...\n");
         
@@ -1202,8 +1164,7 @@ string PreClusterCommand::mergeGroupCounts(string newcount, string newname){
         for (int i = 0; i < groups.size(); i++)  { ct.addGroup(groups[i]); } //add groups
         ct.zeroOutTable();
         
-        ifstream inNames;
-        util.openInputFile(newname, inNames);
+        ifstream inNames; util.openInputFile(newname, inNames);
         
         /*
          newname looks like:
@@ -1216,24 +1177,24 @@ string PreClusterCommand::mergeGroupCounts(string newcount, string newname){
          
          */
         
-        time_t start = time(NULL);
+        time_t start = time(nullptr);
         long long count = 0;
         
         string group, unique_sequence;
         int numDups;
         
         //build table
-        vector<string> namesOfSeqs;
+        unordered_set<string> namesOfSeqs;
         while (!inNames.eof()) {
             
             if (m->getControl_pressed()) { break; }
             
-            inNames >> group; util.gobble(inNames);
-            inNames >> unique_sequence; util.gobble(inNames);
-            inNames >> numDups; util.gobble(inNames);
+            inNames >> group; gobble(inNames);
+            inNames >> unique_sequence; gobble(inNames);
+            inNames >> numDups; gobble(inNames);
             
             ct.setAbund(unique_sequence, group, numDups); count++;
-            namesOfSeqs.push_back(unique_sequence);
+            namesOfSeqs.insert(unique_sequence);
             
             //report progress
             if((count) % 1000 == 0){	m->mothurOutJustToScreen(toString(count) + "\n"); 		}
@@ -1243,17 +1204,13 @@ string PreClusterCommand::mergeGroupCounts(string newcount, string newname){
         
         inNames.close();
         
-        m->mothurOut("It took " + toString(time(NULL) - start) + " secs to merge " + toString(count) + " sequences group data.");
-        start = time(NULL);
+        m->mothurOut("It took " + toString(time(nullptr) - start) + " secs to merge " + toString(count) + " sequences group data.");
+        start = time(nullptr);
         
         ct.printTable(newcount);
         util.mothurRemove(newname);
-        
-        ofstream outAccnos; util.openOutputFile(newname, outAccnos);
-        for (int i = 0; i < namesOfSeqs.size(); i++) { outAccnos << namesOfSeqs[i] << endl; }
-        outAccnos.close();
 
-		return newname;
+		return namesOfSeqs;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "PreClusterCommand", "mergeGroupCounts");
@@ -1302,7 +1259,7 @@ void PreClusterCommand::createProcessesGroups(map<string, vector<string> >& pars
             else { m->mothurOut("[ERROR]: missing files for group " + groups[j] + ", skipping\n"); }
         }
         
-      preClusterData* dataBundle = new preClusterData(thisGroupsParsedFiles, fastafile, countfile, pc_method, align_method, threadNameWriter, newMFile, thisGroups);
+      preClusterData* dataBundle = new preClusterData(thisGroupsParsedFiles, fastafile, countfile, pc_method, align_method, clump, threadNameWriter, newMFile, thisGroups);
       dataBundle->setVariables(diffs, pc_method, align_method, align, match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels, error_dist);
       data.push_back(dataBundle);
 
@@ -1321,7 +1278,7 @@ void PreClusterCommand::createProcessesGroups(map<string, vector<string> >& pars
           }
           else { m->mothurOut("[ERROR]: missing files for group " + groups[j] + ", skipping\n"); }
       }
-    preClusterData* dataBundle = new preClusterData(thisGroupsParsedFiles, fastafile, countfile, pc_method, align_method, threadNameWriter, newMFile, thisGroups);
+    preClusterData* dataBundle = new preClusterData(thisGroupsParsedFiles, fastafile, countfile, pc_method, align_method, clump, threadNameWriter, newMFile, thisGroups);
     dataBundle->setVariables(diffs, pc_method, align_method, align, match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels, error_dist);
 
     driverGroups(dataBundle);
