@@ -20,7 +20,6 @@ class RareFactCommand : public Command {
 	
 public:
 	RareFactCommand(string);
-	RareFactCommand();	
 	~RareFactCommand(){}
 	
 	vector<string> setParameters();
@@ -38,7 +37,6 @@ public:
 private:
 	
 	vector<Display*> rDisplays;
-	Rarefact* rCurve;
 	int nIters, abund, processors, alpha;
 	float freq;
 	
@@ -48,10 +46,10 @@ private:
 	vector<string>  Estimators;
 	vector<string> inputFileNames, outputNames;
 	vector<string> Groups;
-	string outputDir;
 	
 	vector<string> parseSharedFile(string, map<string, set<int> >&);
 	vector<string> createGroupFile(vector<string>&, map<int, string>);
+    void fillRDisplays(map<string, string>, map<int, string>&, int);
 };
 
 #endif
