@@ -33,7 +33,7 @@ public:
 	
 	
 private:
-	set<string> names;
+    unordered_set<string> names;
 	string accnosfile, phylipfile, columnfile;
 	bool abort;
 	vector<string> outputNames;
