@@ -104,7 +104,7 @@ string RemoveGroupsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-RemoveGroupsCommand::RemoveGroupsCommand(string option)  {
+RemoveGroupsCommand::RemoveGroupsCommand(string option) : Command()  {
 	try {
 
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -241,12 +241,6 @@ RemoveGroupsCommand::RemoveGroupsCommand(string option)  {
 			if ((phylipfile == "") && (columnfile == "") && (fastafile == "") && (namefile == "") && (countfile == "") && (groupfile == "")  && (designfile == "") && (sharedfile == "") && (listfile == "") && (taxfile == ""))  { m->mothurOut("[ERROR]: You must provide at least one of the following: fasta, name, taxonomy, group, shared, design, count, phylip, column or list.\n");  abort = true; }
 			if (((groupfile == "") && (countfile == "")) && ((namefile != "") || (fastafile != "") || (listfile != "") || (taxfile != "")))  { m->mothurOut("[ERROR]: If using a fasta, name, taxonomy, group or list, then you must provide a group or count file.\n");  abort = true; }
             
-            if (countfile == "") {
-                if ((namefile == "") && ((fastafile != "") || (taxfile != ""))){
-                    vector<string> files; files.push_back(fastafile); files.push_back(taxfile);
-                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-                }
-            }
 		}
 		
 	}
@@ -306,7 +300,7 @@ int RemoveGroupsCommand::execute(){
             
             vector<string> newSeqs = ct.getNamesOfSeqs(); //names of seqs left after removing groups
             
-            set<string> goodNames = util.mothurConvert(newSeqs);
+            unordered_set<string> goodNames = util.mothurConvert(newSeqs);
             
             for (int i = 0; i < namesOfSeqs.size(); i++) {
                 if (goodNames.count(namesOfSeqs[i]) == 0) { //you aren't on good list
@@ -428,11 +422,8 @@ void RemoveGroupsCommand::readFasta(){
         variables["[extension]"] = util.getExtension(fastafile);
 		string outputFileName = getOutputFileName("fasta", variables);
 		
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-		
-		ifstream in;
-		util.openInputFile(fastafile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(fastafile, in);
 		string name;
 		
 		bool wroteSomething = false;
@@ -459,7 +450,7 @@ void RemoveGroupsCommand::readFasta(){
 					}else { removedCount++; }
 				}
 			}
-			util.gobble(in);
+			gobble(in);
 		}
 		in.close();	
 		out.close();
@@ -508,7 +499,7 @@ void RemoveGroupsCommand::readShared(){
 		bool wroteSomething = false;
         bool printHeaders = true;
 		
-		while(lookup != NULL) {
+		while(lookup != nullptr) {
 			
 			variables["[tag]"] = lookup->getLabel();
             string outputFileName = getOutputFileName("shared", variables);
@@ -556,7 +547,7 @@ void RemoveGroupsCommand::readList(){
         bool wroteSomething = false;
 		int removedCount = 0;
 		
-		while(list != NULL) {
+		while(list != nullptr) {
 			
 			removedCount = 0;
 			
@@ -644,11 +635,9 @@ void RemoveGroupsCommand::readName(){
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(namefile));
         variables["[extension]"] = util.getExtension(namefile);
 		string outputFileName = getOutputFileName("name", variables);	
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
 		
-		ifstream in;
-		util.openInputFile(namefile, in);
+        ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(namefile, in);
 		string name, firstCol, secondCol;
 		
 		bool wroteSomething = false;
@@ -657,8 +646,8 @@ void RemoveGroupsCommand::readName(){
 		while(!in.eof()){
 			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
 			
-			in >> firstCol;		util.gobble(in);		
-			in >> secondCol;	util.gobble(in);
+			in >> firstCol;		gobble(in);		
+			in >> secondCol;	gobble(in);
 			
 			vector<string> parsedNames;
 			util.splitAtComma(secondCol, parsedNames);
@@ -722,11 +711,9 @@ void RemoveGroupsCommand::readGroup(){
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(groupfile));
         variables["[extension]"] = util.getExtension(groupfile);
 		string outputFileName = getOutputFileName("group", variables);	
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
 		
-		ifstream in;
-		util.openInputFile(groupfile, in);
+        ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(groupfile, in);
 		string name, group;
 		
 		bool wroteSomething = false;
@@ -744,7 +731,7 @@ void RemoveGroupsCommand::readGroup(){
 				out << name << '\t' << group << endl;
 			}else {  removedCount++;  }
 			
-			util.gobble(in);
+			gobble(in);
 		}
 		in.close();
 		out.close();
@@ -769,7 +756,7 @@ void RemoveGroupsCommand::readDesign(){
         variables["[extension]"] = util.getExtension(designfile);
 		string outputFileName = getOutputFileName("design", variables);
 		
-        DesignMap designMap(designfile);
+        DesignMap designMap(designfile);  if (m->getControl_pressed()) {  return ; }
         
         vector<string> groupsToKeep;
         vector<string> allGroups = designMap.getNamesGroups();
@@ -790,6 +777,8 @@ void RemoveGroupsCommand::readDesign(){
         
         out.close();
 		
+        names.clear(); names = util.mothurConvert(Groups);
+        
         int removedCount = allGroups.size() - numGroupsFound;
         
 		if (wroteSomething == false) {  m->mothurOut("Your file contains only groups from the groups you wish to remove.\n");   }
@@ -812,11 +801,9 @@ void RemoveGroupsCommand::readTax(){
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(taxfile));
         variables["[extension]"] = util.getExtension(taxfile);
 		string outputFileName = getOutputFileName("taxonomy", variables);
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
 		
-		ifstream in;
-		util.openInputFile(taxfile, in);
+        ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(taxfile, in);
 		string name, tax;
 		
 		bool wroteSomething = false;
@@ -825,8 +812,8 @@ void RemoveGroupsCommand::readTax(){
 		while(!in.eof()){
 			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
 			
-            in >> name; util.gobble(in);
-            tax = util.getline(in); util.gobble(in);
+            in >> name; gobble(in);
+            tax = util.getline(in); gobble(in);
 			
 			//if this name is in the accnos file
 			if (names.count(name) == 0) {
@@ -862,11 +849,10 @@ void RemoveGroupsCommand::readPhylip(){
         variables["[extension]"] = util.getExtension(phylipfile);
         string outputFileName = getOutputFileName("phylip", variables);
         
-        ifstream in;
-        util.openInputFile(phylipfile, in);
+        ifstream in; util.openInputFile(phylipfile, in);
         
         float distance;
-        int square, nseqs;
+        int square, nseqs; square = 0;
         string name;
         unsigned int row;
         set<unsigned int> rows; //converts names in names to a index
@@ -994,7 +980,7 @@ void RemoveGroupsCommand::readPhylip(){
             
             ifstream in3;
             util.openInputFile(outputFileName+".temp", in3);
-            in3 >> nseqs; util.gobble(in3);
+            in3 >> nseqs; gobble(in3);
             char buffer[4096];
             while (!in3.eof()) {
                 in3.read(buffer, 4096);
@@ -1023,11 +1009,8 @@ void RemoveGroupsCommand::readColumn(){
         string outputFileName = getOutputFileName("column", variables);
         outputTypes["column"].push_back(outputFileName);  outputNames.push_back(outputFileName);
         
-        ofstream out;
-        util.openOutputFile(outputFileName, out);
-        
-        ifstream in;
-        util.openInputFile(columnfile, in);
+        ofstream out; util.openOutputFile(outputFileName, out);
+        ifstream in; util.openInputFile(columnfile, in);
         
         set<string> removeNames;
         string firstName, secondName;
@@ -1037,7 +1020,7 @@ void RemoveGroupsCommand::readColumn(){
             
             if (m->getControl_pressed()) { out.close(); in.close(); return; }
             
-            in >> firstName >> secondName >> distance; util.gobble(in);
+            in >> firstName >> secondName >> distance; gobble(in);
             
             //is either names in the accnos file
             if (names.count(firstName) != 0)       {
@@ -1091,7 +1074,7 @@ void RemoveGroupsCommand::fillNames(){
 //**********************************************************************************************************************
 void RemoveGroupsCommand::fillGroupsFromDesign(){
     try {
-        DesignMap designMap(designfile);
+        DesignMap designMap(designfile);  if (m->getControl_pressed()) {  return ; }
         Groups = designMap.getNamesGroups(Sets);
     }
     catch(exception& e) {
