@@ -20,7 +20,7 @@ class RenameSeqsCommand : public Command {
     
 public:
 	RenameSeqsCommand(string);
-	~RenameSeqsCommand() {}
+	~RenameSeqsCommand() = default;
 	
 	vector<string> setParameters();
 	string getCommandName()			{ return "rename.seqs";		}
@@ -38,18 +38,21 @@ public:
 	
 private:
     
-	string fastaFile, nameFile, groupfile,  placement, delim, countfile, qualfile, contigsfile, fileFile, mapFile, taxfile;
+	string fastaFile, fastqfile, listfile, nameFile, groupfile,  placement, delim, countfile, qualfile, contigsfile, fileFile, mapFile, taxfile, groupName;
 	vector<string> outputNames;
-	bool abort;
+	bool abort, ignoreNew, gz;
 	
 	map<string, string> nameMap;
-    int readQual(map<string, string>&);
-    int readTax(map<string, string>&);
-    int readContigs(map<string, string>&);
-    int readFasta(string, map<string, string>&);
-    int processFile(map<string, string>&);
+    void readQual(map<string, string>&);
+    void readTax(map<string, string>&);
+    void readContigs(map<string, string>&);
+    void readList(map<string, string>&);
+    void readFasta(map<string, string>&);
+    string readFastq(map<string, string>&);
+    int processFile();
     int readMapFile(map<string, string>&);
-    vector< map<string, string> > readFiles();
+    vector< vector<string> > readFiles(map<int, string>&, bool&);
+    void processNameGroupCountFiles(map<string, string>&, map<string, string>&);
     
 };
 
