@@ -82,7 +82,7 @@ string SensSpecCommand::getOutputPattern(string type) {
 }
 //***************************************************************************************************************
 
-SensSpecCommand::SensSpecCommand(string option)  {
+SensSpecCommand::SensSpecCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -186,13 +186,13 @@ int SensSpecCommand::execute(){
 	try{
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 
-        int startTime = time(NULL);
+        int startTime = time(nullptr);
 
 		processListFile();
 
         if (m->getControl_pressed()) { util.mothurRemove(sensSpecFileName); return 0; }
 
-        m->mothurOut("It took " + toString(time(NULL) - startTime) + " to run sens.spec.\n");
+        m->mothurOut("It took " + toString(time(nullptr) - startTime) + " to run sens.spec.\n");
 		m->mothurOut("\nOutput File Names: \n"); m->mothurOut(sensSpecFileName+"\n\n");
 
 		return 0;
@@ -220,7 +220,24 @@ int SensSpecCommand::process(ListVector*& list, bool& getCutoff, string& origCut
         string nameOrCount = "";
         string thisNamefile = "";
         if (countfile != "") { nameOrCount = "count"; thisNamefile = countfile; CountTable ct; ct.readTable(countfile, false, false); }
-        else if (namefile != "") { nameOrCount = "name"; thisNamefile = namefile; }
+        else if (namefile != "") {
+            nameOrCount = "name"; thisNamefile = namefile;
+            //remove redundant names from list
+            map<string, int> thisNames = util.readNames(namefile);
+            for (int i = 0; i < list->getNumBins(); i++) {
+                string bin = list->get(i);
+                vector<string> binNames; util.splitAtChar(bin, binNames, ',');
+                string newBin = "";
+                for (int j = 0; j < binNames.size(); j++) {
+                    map<string, int>::iterator it = thisNames.find(binNames[j]);
+                    if (it != thisNames.end()) {
+                        newBin += "," + binNames[j];
+                    }
+                }
+                newBin = newBin.substr(1);
+                list->set(i, newBin);
+            }
+        }
         
         string distfile = columnfile;
         if (format == "phylip") { distfile = phylipfile; }
@@ -254,7 +271,7 @@ void SensSpecCommand::processListFile(){
         
         ListVector* list = util.getNextList(input, allLines, userLabels, processedLabels, lastLabel);
                
-        while (list != NULL) {
+        while (list != nullptr) {
                    
             if (m->getControl_pressed()) { delete list; break; }
                    
