@@ -17,8 +17,7 @@ class SetCurrentCommand : public Command {
 	
 public:
 	SetCurrentCommand(string);
-	SetCurrentCommand();
-	~SetCurrentCommand() {}
+	~SetCurrentCommand() = default;
 	
 	vector<string> setParameters();
 	string getCommandName()			{ return "set.current";	}
@@ -40,8 +39,8 @@ private:
 	string clearTypes;
 	vector<string> types;
 	
-	string accnosfile, phylipfile, columnfile, listfile, rabundfile, sabundfile, namefile, groupfile, designfile, taxonomyfile, biomfile, countfile, summaryfile, currentFile, outputDir;
-	string orderfile, treefile, sharedfile, ordergroupfile, relabundfile, fastafile, qualfile, sfffile, oligosfile, processors, flowfile, filefile, constaxonomyfile, contigsreportfile;
+	string accnosfile, phylipfile, columnfile, listfile, rabundfile, sabundfile, namefile, groupfile, designfile, taxonomyfile, biomfile, countfile, summaryfile, currentFile,  samplefile;
+	string orderfile, treefile, sharedfile, ordergroupfile, relabundfile, fastafile, qualfile, sfffile, oligosfile, processors, flowfile, filefile, constaxonomyfile, contigsreportfile, clrfile;
 
     int readCurrentFiles();
 	
