@@ -88,7 +88,7 @@ string SummarySharedCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-SummarySharedCommand::SummarySharedCommand(string option)  {
+SummarySharedCommand::SummarySharedCommand(string option) : Command()  {
 	try {
 
 		if(option == "help") {  help(); abort = true; calledHelp = true; }
@@ -370,7 +370,7 @@ int SummarySharedCommand::execute(){
 		
         vector<string> currentLabels = lookup->getOTUNames();
         
-        while (lookup != NULL) {
+        while (lookup != nullptr) {
             
             if (m->getControl_pressed()) { delete lookup; break; }
             
