@@ -60,7 +60,7 @@ class FileFile {
     
 public:
     FileFile(string, string); //provide file file and read file, mode (ie. contigs) mode options include: mimarks,contigs,parseFastq,renameSeqs,sra,parsefastqpacbio
-    ~FileFile() {}
+    ~FileFile() = default;
     
     vector< vector<string> > getFiles() { return files; }
     
@@ -76,7 +76,7 @@ protected:
     MothurOut* m;
     CurrentFile* current;
     Utils util;
-    string filename, mode, inputDir, mpath;
+    string filename, mode, mpath;
     bool gz, hasIndex, columnWithGroups;
     int fileOption; //1 -> 2 column(3 forms of 2 column), 2 -> 3 column, 3 -> 4 column
     vector< vector<string> > files;
