@@ -31,7 +31,7 @@ int GroupMap::addSeq(string name, string group) {
         util.checkName(name);
         it = groupmap.find(name);
         
-        if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + name + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+        if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + name + ", sequence names must be unique. Please correct.\n");   }
         else {
             groupmap[name] = group;	//store data in map
             seqsPerGroup[group]++;  //increment number of seqs in that group
@@ -93,8 +93,8 @@ int GroupMap::readMap(vector<string> g) {
             while (!fileHandle.eof()) {
                 if (m->getControl_pressed()) { fileHandle.close();  return 1; }
                 
-                fileHandle >> seqName; util.gobble(fileHandle);
-                fileHandle >> seqGroup; util.gobble(fileHandle);
+                fileHandle >> seqName; gobble(fileHandle);
+                fileHandle >> seqGroup; gobble(fileHandle);
                 
                 if (util.inUsersGroups(seqGroup, g)) {
                     util.checkGroupName(seqGroup);
@@ -149,7 +149,7 @@ int GroupMap::readMap() {
             util.checkName(seqName);
             it = groupmap.find(seqName);
             
-            if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+            if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");   }
             else {
                 groupmap[seqName] = seqGroup;	//store data in map
                 seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
@@ -174,7 +174,7 @@ int GroupMap::readMap() {
                     util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
-                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");   }
                     else {
                         groupmap[seqName] = seqGroup;	//store data in map
                         seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
@@ -200,7 +200,7 @@ int GroupMap::readMap() {
                     util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
-                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");   }
                     else {
                         groupmap[seqName] = seqGroup;	//store data in map
                         seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
@@ -251,7 +251,7 @@ int GroupMap::readDesignMap() {
                     util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
-                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");   }
                     else {
                         groupmap[seqName] = seqGroup;	//store data in map
                         seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
@@ -277,7 +277,7 @@ int GroupMap::readDesignMap() {
                     util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
-                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");   }
                     else {
                         groupmap[seqName] = seqGroup;	//store data in map
                         seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
@@ -327,7 +327,7 @@ int GroupMap::readMap(string filename) {
                     util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
-                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your group file contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your group file contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");   }
                     else {
                         groupmap[seqName] = seqGroup;	//store data in map
                         seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
@@ -353,7 +353,7 @@ int GroupMap::readMap(string filename) {
                     util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
-                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your group file contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your group file contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");   }
                     else {
                         groupmap[seqName] = seqGroup;	//store data in map
                         seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
@@ -402,7 +402,7 @@ int GroupMap::readDesignMap(string filename) {
                     util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
-                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");   }
                     else {
                         groupmap[seqName] = seqGroup;	//store data in map
                         seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
@@ -428,7 +428,7 @@ int GroupMap::readDesignMap(string filename) {
                     util.checkName(seqName);
                     it = groupmap.find(seqName);
                     
-                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("Your designfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");   }
                     else {
                         groupmap[seqName] = seqGroup;	//store data in map
                         seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
@@ -527,7 +527,7 @@ void GroupMap::setGroup(string sequenceName, string groupN) {
 	util.checkName(sequenceName);
 	it = groupmap.find(sequenceName);
 	
-	if (it != groupmap.end()) {  m->mothurOut("Your groupfile contains more than 1 sequence named " + sequenceName + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+	if (it != groupmap.end()) {  m->mothurOut("Your groupfile contains more than 1 sequence named " + sequenceName + ", sequence names must be unique. Please correct.\n");   }
 	else {
 		groupmap[sequenceName] = groupN;	//store data in map
 		seqsPerGroup[groupN]++;  //increment number of seqs in that group
