@@ -153,6 +153,46 @@ float SharedRAbundFloatVector::remove(int bin){
         exit(1);
     }
 }
+/***********************************************************************/
+
+float SharedRAbundFloatVector::remove(vector<int> bins){
+    try {
+        if (bins.size() == 0) { return 0; }
+        
+        int numRemoved = 0;
+        vector<float> newData; int binIndex = 0;
+        for (int i = 0; i < data.size(); i++) {
+            if (m->getControl_pressed()) { break; }
+            
+            if (i != bins[binIndex]) {
+                newData.push_back(data[i]);
+            }else if (i == bins[binIndex]) {
+                binIndex++;
+                numRemoved += data[i];
+                if (binIndex > bins.size()) { //removed all bins
+                    newData.insert(newData.end(), data.begin()+i, data.end()); //add rest of good bins
+                    break;
+                }
+            }
+        }
+        
+        data = newData;
+        numBins = data.size();
+        
+        vector<float>::iterator it = max_element(data.begin(), data.end());
+        maxRank = *it;
+        
+        numSeqs -= numRemoved;
+        
+        return numRemoved;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "SharedRASharedRAbundFloatVectorbundVector", "remove");
+        exit(1);
+    }
+}
+
+
 /***********************************************************************/
 void SharedRAbundFloatVector::resize(int size){
     data.resize(size);
@@ -240,7 +280,7 @@ SAbundVector SharedRAbundFloatVector::getSAbundVector() {
 
 /***********************************************************************/
 
-OrderVector SharedRAbundFloatVector::getOrderVector(map<string,int>* nameMap = NULL) {
+OrderVector SharedRAbundFloatVector::getOrderVector(map<string,int>* nameMap = nullptr) {
     try {
  m->mothurOut("[ERROR]: can not convert SharedRAbundVectors to an ordervector, ordervectors assume no zero OTUS.\n"); m->setControl_pressed(true);
  OrderVector o; return o; 
