@@ -20,6 +20,6 @@ NoAlign::~NoAlign(){	/*	do nothing	*/	}
 
 /**************************************************************************************************/
 
-void NoAlign::align(string A, string B){	}
+void NoAlign::align(string A, string B, bool createBaseMap){	}
 
 /**************************************************************************************************/
