@@ -10,7 +10,7 @@
 
 
 /***********************************************************************/
-OptiFitCluster::OptiFitCluster(OptiData* mt, ClusterMetric* met, long long ns, string crit) : Cluster(), matrix(mt), metric(met), numComboSingletons(ns), criteria(crit) {
+OptiFitCluster::OptiFitCluster(OptiData* mt, ClusterMetric* met, long long ns) : Cluster(), matrix(mt), metric(met), numComboSingletons(ns) {
     m = MothurOut::getInstance();
     maxRefBinNumber = 0;
     closed = false;
@@ -85,8 +85,6 @@ int OptiFitCluster::initialize(double& value, bool randomize, vector<vector< str
         
         double comboValue = metric->getValue(combotruePositives, combotrueNegatives, combofalsePositives, combofalseNegatives);
         
-        //cout << "combo intial mcc " << comboValue << '\t' << combotruePositives << '\t' << combotrueNegatives << '\t' << combofalsePositives << '\t' << combofalseNegatives << endl;
-        
         //add insert location
         seqBin[bins.size()] = -1;
         insertLocation = bins.size();
@@ -95,11 +93,7 @@ int OptiFitCluster::initialize(double& value, bool randomize, vector<vector< str
         
         if (randomize) { util.mothurRandomShuffle(randomizeSeqs); }
         
-        if (criteria == "fit") {
-            double temp1, temp2, temp3, temp4;
-            getFitStats(temp1, temp2, temp3, temp4);
-            value = metric->getValue(temp1, temp2, temp3, temp4);
-        }else { value = comboValue; }
+        value = comboValue;
         
         return value;
     }
@@ -114,7 +108,6 @@ int OptiFitCluster::initialize(double& value, bool randomize, vector<vector< str
  * keep or move the sequence to the OTU where the `metric` is the largest - flip a coin on ties */
 bool OptiFitCluster::update(double& listMetric) {
     try {
-        double comboCaused, fitCaused, bothCaused; comboCaused = 0; fitCaused = 0; bothCaused = 0;
         //for each sequence (singletons removed on read)
         for (int i = 0; i < randomizeSeqs.size(); i++) {
             
@@ -177,6 +170,7 @@ bool OptiFitCluster::update(double& listMetric) {
                 for (set<long long>::iterator itClose = closeSeqs.begin(); itClose != closeSeqs.end(); itClose++) { binsToTry.insert(seqBin[*itClose]); }
                 
                 //merge into each "close" otu
+                vector<vector<double> > ties; vector<vector<double> > ties0;
                 for (set<long long>::iterator it = binsToTry.begin(); it != binsToTry.end(); it++) {
                     //reset tn, tp,fp,fn values to original bin
                     tn[0] = fittrueNegatives; tp[0] = fittruePositives; fp[0] = fitfalsePositives; fn[0] = fitfalseNegatives;
@@ -195,28 +189,33 @@ bool OptiFitCluster::update(double& listMetric) {
                     double newComboMetric = metric->getValue(tp[1], tn[1], fp[1], fn[1]); //score when sequence is moved
                     double newFitMetric = metric->getValue(tp[0], tn[0], fp[0], fn[0]); //score when sequence is moved
                     //new best
-                    if ((newFitMetric > bestMetric[0]) || (newComboMetric > bestMetric[1])) {
-                        bool move = false;
-                        if ((newComboMetric > bestMetric[1]) && (newFitMetric > bestMetric[0])) { bothCaused++; }
-                        else if (newComboMetric < bestMetric[1]) {
-                            fitCaused++;
-                        }
-                        else if (newFitMetric < bestMetric[0]) { comboCaused++; }
+                    if (newComboMetric > bestMetric[1]) {
+                        ties.clear(); ties0.clear();
+                        bestMetric[1] = newComboMetric; bestBin[1] = (*it); bestTp[1] = tp[1]; bestTn[1] = tn[1]; bestFp[1] = fp[1]; bestFn[1] = fn[1];
+                        bestMetric[0] = newFitMetric; bestBin[0] = (*it); bestTp[0] = tp[0]; bestTn[0] = tn[0]; bestFp[0] = fp[0]; bestFn[0] = fn[0];
+                        vector<double> tie; tie.push_back(bestMetric[1]); tie.push_back(bestBin[1]); tie.push_back(bestTp[1]);
+                        tie.push_back(bestTn[1]); tie.push_back(bestFp[1]); tie.push_back(bestFn[1]); ties.push_back(tie);
+                        vector<double> tie0; tie0.push_back(bestMetric[0]); tie0.push_back(bestBin[0]); tie0.push_back(bestTp[0]);
+                        tie0.push_back(bestTn[0]); tie0.push_back(bestFp[0]); tie0.push_back(bestFn[0]); ties0.push_back(tie0);
+
                         
-                        if (criteria == "both") {
-                            move = true;
-                        }else if (criteria == "fit") {
-                            if (newFitMetric > bestMetric[0]) { move = true;  }
-                        }else if (criteria == "combo") {
-                            if (newComboMetric > bestMetric[1]) { move = true; }
-                        }
-                        if (move) {
-                            bestMetric[0] = newFitMetric; bestBin[0] = (*it); bestTp[0] = tp[0]; bestTn[0] = tn[0]; bestFp[0] = fp[0]; bestFn[0] = fn[0];
-                            bestMetric[1] = newComboMetric; bestBin[1] = (*it); bestTp[1] = tp[1]; bestTn[1] = tn[1]; bestFp[1] = fp[1]; bestFn[1] = fn[1];
-                        }
+                    }else if (newComboMetric == bestMetric[1]) {
+                        bestMetric[1] = newComboMetric; bestBin[1] = (*it); bestTp[1] = tp[1]; bestTn[1] = tn[1]; bestFp[1] = fp[1]; bestFn[1] = fn[1];
+                        bestMetric[0] = newFitMetric; bestBin[0] = (*it); bestTp[0] = tp[0]; bestTn[0] = tn[0]; bestFp[0] = fp[0]; bestFn[0] = fn[0];
+                        vector<double> tie; tie.push_back(bestMetric[1]); tie.push_back(bestBin[1]); tie.push_back(bestTp[1]);
+                        tie.push_back(bestTn[1]); tie.push_back(bestFp[1]); tie.push_back(bestFn[1]); ties.push_back(tie);
+                        vector<double> tie0; tie0.push_back(bestMetric[0]); tie0.push_back(bestBin[0]); tie0.push_back(bestTp[0]);
+                        tie0.push_back(bestTn[0]); tie0.push_back(bestFp[0]); tie0.push_back(bestFn[0]); ties0.push_back(tie0);
+
                     }
                 }
                 
+                if (ties.size() > 1) {
+                    int randomTie = util.getRandomIndex((int)ties.size()-1);
+                    bestMetric[1] = ties[randomTie][0]; bestBin[1] = ties[randomTie][1]; bestTp[1] = ties[randomTie][2]; bestTn[1] = ties[randomTie][3]; bestFp[1] = ties[randomTie][4]; bestFn[1] = ties[randomTie][5];
+                    bestMetric[0] = ties0[randomTie][0]; bestBin[0] = ties0[randomTie][1]; bestTp[0] = ties0[randomTie][2]; bestTn[0] = ties0[randomTie][3]; bestFp[0] = ties0[randomTie][4]; bestFn[0] = ties0[randomTie][5];
+                }
+                
                 //how to choose the best bin if they differ????
                 long long newBin = bestBin[1];
                 
@@ -239,15 +238,9 @@ bool OptiFitCluster::update(double& listMetric) {
             }
         }
         
-        if (criteria == "fit") {
-            double temp1, temp2, temp3, temp4;
-            getFitStats(temp1, temp2, temp3, temp4);
-            listMetric = metric->getValue(temp1, temp2, temp3, temp4);
-        }
-        else { listMetric = metric->getValue(combotruePositives, combotrueNegatives, combofalsePositives, combofalseNegatives); }
+        listMetric = metric->getValue(combotruePositives, combotrueNegatives, combofalsePositives, combofalseNegatives); 
         
-        //cout << fittruePositives << '\t' << fittrueNegatives << '\t' << fitfalsePositives << '\t' << fitfalseNegatives << endl;
-        //cout << "combo improved " << comboCaused << " fit improved " << fitCaused << " both improved " << bothCaused << '\t' << listMetric << '\t' << endl;
+       
         if (m->getDebug()) { ListVector* list = getList(); list->print(cout); delete list; }
         
         return 0;
@@ -373,7 +366,7 @@ ListVector* OptiFitCluster::getList() {
         ListVector* list = new ListVector();
         ListVector* singleton = matrix->getListSingle();
         
-        if (singleton != NULL) { //add in any sequences above cutoff in read. Removing these saves clustering time.
+        if (singleton != nullptr) { //add in any sequences above cutoff in read. Removing these saves clustering time.
             for (int i = 0; i < singleton->getNumBins(); i++) {
                 if (singleton->get(i) != "") {
                     list->push_back(singleton->get(i));
@@ -433,73 +426,6 @@ ListVector* OptiFitCluster::getFittedList(string label, bool includerefs) {
             }else { unFitted.insert(seqNumber); }
         }
         
-        //numFitSeqs does not include any kind of singleton
-        long long numUnFitted = (numFitSeqs + numFitSingletons - numListSeqs); //getNumFitTrueSingletons are fit reads that have no dists in the matrix. This can be confusing, think of it like this: there are true singletons, meaning we don't care if you are a ref or fit and you have no dists below the cutoff. This means you will be in your own OTU no matter what we do. There are fitSIngletons, meaning you are a fit sequence and have no dists below the cutoff that coorespond to other fit seqs ( NOTE: you may or may not have dists to ref seqs or you could be a true singleton or a just a singleton because of the references chosen).
-        
-        long long numSingletonBins = 0;
-        
-        if ((label != "") && (numUnFitted != 0)) {
-            
-            m->mothurOut("\nFitted " + toString(numListSeqs) + " sequences to " + toString(newBins.size()) + " existing OTUs.\n");
-            
-            if (!closed) { //cluster the unfitted seqs separately
-                m->mothurOut(toString(numUnFitted) + " sequences were unable to be fitted existing OTUs, excluding singletons.\n");
-                
-                m->mothurOut("\n**************** Clustering the unfitted sequences ****************\n");
-                
-                OptiData* unFittedMatrix = matrix->extractMatrixSubset(unFitted);
-                
-                ListVector* unfittedList = clusterUnfitted(unFittedMatrix, label);
-                
-                if (unfittedList != NULL) {
-                    
-                    m->mothurOut("The unfitted sequences clustered into " + toString(unfittedList->getNumBins()) + " new OTUs.\n"); //+unFittedMatrix->getNumSingletons()+ matrix->getNumFitSingletons()
-                    
-                    for (int i = 0; i < unfittedList->getNumBins(); i++) {
-                        string bin = unfittedList->get(i);
-                        if (bin != "") { list->push_back(unfittedList->get(i)); }
-                    }
-                    delete unfittedList;
-                }
-                
-                m->mothurOut("\n*******************************************************************\n\n");
-                
-                //add in singletons
-                ListVector* singleton = matrix->getFitListSingle();
-                
-                if (singleton != NULL) { //add in any sequences above cutoff in read. Removing these saves clustering time.
-                    for (int i = 0; i < singleton->getNumBins(); i++) {
-                        if (m->getControl_pressed()) { break; }
-                        if (singleton->get(i) != "") {
-                            list->push_back(singleton->get(i));
-                        }
-                    }
-                    numSingletonBins += singleton->getNumBins();
-                    delete singleton;
-                }
-            
-                //add in singletons
-                ListVector* unFitsingleton = unFittedMatrix->getListSingle();
-                
-                if (unFitsingleton != NULL) { //add in any sequences above cutoff in read. Removing these saves clustering time.
-                    for (int i = 0; i < unFitsingleton->getNumBins(); i++) {
-                        if (m->getControl_pressed()) { break; }
-                        if (unFitsingleton->get(i) != "") {
-                            list->push_back(unFitsingleton->get(i));
-                        }
-                    }
-                    numSingletonBins += unFitsingleton->getNumBins();
-                    delete unFitsingleton;
-                }
-                
-                delete unFittedMatrix;
-            }else { m->mothurOut("Disregarding sequences that were unable to be fitted existing OTUs.\n");  }
-        }else {
-            if (label != "") {
-                m->mothurOut("\nFitted all " + toString(list->getNumSeqs()) + " sequences to existing OTUs. \n");
-            }
-        }
-        
         if (denovo || includerefs) { //add in refs
             vector<long long> refs = matrix->getRefSeqs();
             
@@ -520,6 +446,70 @@ ListVector* OptiFitCluster::getFittedList(string label, bool includerefs) {
             }
         }
         
+        //numFitSeqs does not include any kind of singleton
+        long long numUnFitted = (numFitSeqs + numFitSingletons - numListSeqs); //getNumFitTrueSingletons are fit reads that have no dists in the matrix. This can be confusing, think of it like this: there are true singletons, meaning we don't care if you are a ref or fit and you have no dists below the cutoff. This means you will be in your own OTU no matter what we do. There are fitSingletons, meaning you are a fit sequence and have no dists below the cutoff that coorespond to other fit seqs ( NOTE: you may or may not have dists to ref seqs or you could be a true singleton or a just a singleton because of the references chosen).
+        
+        long long numSingletonBins = 0;
+        if ((label != "") && (numUnFitted != 0)) {
+            
+            m->mothurOut("\nFitted " + toString(numListSeqs) + " sequences to " + toString(newBins.size()) + " existing OTUs.\n");
+            
+            if (!closed) { //cluster the unfitted seqs separately
+                m->mothurOut(toString(numUnFitted) + " sequences were unable to be fitted existing OTUs, excluding singletons.\n");
+                
+                m->mothurOut("\n**************** Clustering the unfitted sequences ****************\n");
+                
+                OptiData* unFittedMatrix = matrix->extractMatrixSubset(unFitted);
+                
+                ListVector* unfittedList = clusterUnfitted(unFittedMatrix, label); //unfittedList includes unfitted singletons
+                
+                if (unfittedList != nullptr) {
+                    
+                    m->mothurOut("The unfitted sequences clustered into " + toString(unfittedList->getNumBins()) + " new OTUs.\n"); //+unFittedMatrix->getNumSingletons()+ matrix->getNumFitSingletons()
+                    
+                    for (int i = 0; i < unfittedList->getNumBins(); i++) {
+                        string bin = unfittedList->get(i);
+                        if (bin != "") { list->push_back(unfittedList->get(i)); }
+                    }
+                    delete unfittedList;
+                }
+                delete unFittedMatrix;
+                
+                m->mothurOut("\n*******************************************************************\n\n");
+                
+                //add in fit singletons 
+                ListVector* singleton = matrix->getFitListSingle();
+                
+                if (singleton != nullptr) { //add in any sequences above cutoff in read. Removing these saves clustering time.
+                    for (int i = 0; i < singleton->getNumBins(); i++) {
+                        if (m->getControl_pressed()) { break; }
+                        if (singleton->get(i) != "") { list->push_back(singleton->get(i)); }
+                    }
+                    numSingletonBins += singleton->getNumBins();
+                    delete singleton;
+                }
+                
+            }else {
+                m->mothurOut("\nSequences that were unable to be fitted existing OTUs will be listed in the *.optifit_scrap.accnos file.\n");
+                unfittedNames = matrix->getNames(unFitted);
+                
+                //add in fit singletons
+                ListVector* singleton = matrix->getFitListSingle();
+                
+                if (singleton != nullptr) { //add in any sequences above cutoff in read. Removing these saves clustering time.
+                    for (int i = 0; i < singleton->getNumBins(); i++) {
+                        if (m->getControl_pressed()) { break; }
+                        if (singleton->get(i) != "") { unfittedNames.insert(singleton->get(i)); }
+                    }
+                    delete singleton;
+                }
+            }
+        }else {
+            if (label != "") {
+                m->mothurOut("\nFitted all " + toString(list->getNumSeqs()) + " sequences to existing OTUs. \n");
+            }
+        }
+        
         vector<string> newLabels = list->getLabels();
         
         for (map<long long, string>::iterator itBin = newBins.begin(); itBin != newBins.end(); itBin++) {
@@ -539,7 +529,7 @@ ListVector* OptiFitCluster::getFittedList(string label, bool includerefs) {
 /***********************************************************************/
 ListVector* OptiFitCluster::clusterUnfitted(OptiData* unfittedMatrix, string label) {
     try {
-        ListVector* list = NULL;
+        ListVector* list = nullptr;
         
         OptiCluster cluster(unfittedMatrix, metric, 0);
         
@@ -561,7 +551,7 @@ ListVector* OptiFitCluster::clusterUnfitted(OptiData* unfittedMatrix, string lab
         
         while ((delta > 0.0001) && (iters < 100)) {
             
-            long start = time(NULL);
+            long start = time(nullptr);
             
             if (m->getControl_pressed()) { break; }
             double oldMetric = listVectorMetric;
@@ -574,7 +564,7 @@ ListVector* OptiFitCluster::clusterUnfitted(OptiData* unfittedMatrix, string lab
             results = cluster.getStats(tp, tn, fp, fn);
             numBins = cluster.getNumBins();
             
-            m->mothurOut(toString(iters) + "\t" + toString(time(NULL) - start) + "\t" + label + "\t" + toString(numBins) + "\t" + label + "\t"+ toString(tp) + "\t" + toString(tn) + "\t" + toString(fp) + "\t" + toString(fn) + "\t");
+            m->mothurOut(toString(iters) + "\t" + toString(time(nullptr) - start) + "\t" + label + "\t" + toString(numBins) + "\t" + label + "\t"+ toString(tp) + "\t" + toString(tn) + "\t" + toString(fp) + "\t" + toString(fn) + "\t");
             
             for (int i = 0; i < results.size(); i++) { m->mothurOut(toString(results[i]) + "\t");  }
             m->mothurOutEndLine();
@@ -618,7 +608,7 @@ long long OptiFitCluster::getNumFitBins() {
         ListVector* list = getFittedList("", false);
         
         int numBins = 0;
-        if (list != NULL) {
+        if (list != nullptr) {
             numBins = list->getNumBins();
             delete list;
         }
