@@ -46,21 +46,21 @@ int singleDriver(singleRarefactData* params){
             for(int i=0;i<params->displays.size();i++){ params->displays[i]->init(params->label); }
             
             RAbundVector lookup(params->order.getNumBins());
-            SAbundVector* rank	= new SAbundVector(params->order.getMaxRank()+1);
+            SAbundVector rank(params->order.getMaxRank()+1);
             params->util.mothurRandomShuffle(params->order);
             
             for(int i=0;i<params->numSeqs;i++){
                 
-                if (params->m->getControl_pressed()) { delete rank; return 0;  }
+                if (params->m->getControl_pressed()) {  return 0;  }
                 
                 int binNumber = params->order.get(i);
                 int abundance = lookup.get(binNumber);
                 
-                rank->set(abundance, rank->get(abundance)-1);
+                rank.set(abundance, rank.get(abundance)-1);
                 abundance++;
                 
                 lookup.set(binNumber, abundance);
-                rank->set(abundance, rank->get(abundance)+1);
+                rank.set(abundance, rank.get(abundance)+1);
                 
                 if((i == 0) || ((i+1) % params->increment == 0) || (params->ends.count(i+1) != 0)){ rcd.updateRankData(rank); }
             }
@@ -68,8 +68,6 @@ int singleDriver(singleRarefactData* params){
             if((params->numSeqs % params->increment != 0) || (params->ends.count(params->numSeqs) != 0)){ rcd.updateRankData(rank); }
             
             for(int i=0;i<params->displays.size();i++){ params->displays[i]->reset(); }
-            
-            delete rank;
         }
         
         return 0;
@@ -100,7 +98,7 @@ int Rarefact::getCurve(float percentFreq = 0.01, int nIters = 1000){
         }
         
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<singleRarefactData*> data;
         
         //Lauch worker threads
@@ -112,7 +110,7 @@ int Rarefact::getCurve(float percentFreq = 0.01, int nIters = 1000){
             
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(singleDriver, dataBundle));
+            workerThreads.push_back(new std::thread(singleDriver, dataBundle));
         }
         
         //make copy of lookup so we don't get access violations
@@ -140,7 +138,7 @@ int Rarefact::getCurve(float percentFreq = 0.01, int nIters = 1000){
 /**************************************************************************************************/
 struct sharedRarefactData {
     
-    long long nIters, numGroupComb;
+    long long nIters;
     MothurOut* m;
     Utils util;
     vector<SharedRAbundVector*> lookup;
@@ -149,14 +147,14 @@ struct sharedRarefactData {
     bool jumble;
     
     sharedRarefactData(){}
-    sharedRarefactData(long long st, Utils u, vector<SharedRAbundVector*>& o, vector<Display*>& dis, string l, long long ns) {
+    sharedRarefactData(long long st, Utils u, vector<SharedRAbundVector*>& o, vector<Display*>& dis, string l, bool ns) {
         m = MothurOut::getInstance();
         nIters = st;
         util = u;
         lookup = o;
         displays = dis;
         label = l;
-        numGroupComb = ns;
+        jumble = ns;
     }
     ~sharedRarefactData(){ for(int i = 0; i < lookup.size(); i++) {  delete lookup[i]; } }
 };
@@ -197,14 +195,14 @@ int sharedDriver(sharedRarefactData* params){
             
             vector<SharedRAbundVector*> subset;
             //send each group one at a time
-            for (int k = 0; k < params->lookup.size(); k++) {
+            for (int k = 1; k < params->lookup.size(); k++) {
                 if (params->m->getControl_pressed()) {  delete merge;  return 0;  }
                 
                 subset.clear(); //clears out old pair of sharedrabunds
                 //add in new pair of sharedrabunds
                 subset.push_back(merge); subset.push_back(params->lookup[k]);
                 
-                rcd.updateSharedData(subset, k+1, params->numGroupComb);
+                rcd.updateSharedData(subset, k+1); //, params->numGroupComb
                 mergeVectors(merge, params->lookup[k], params->m);
             }
             
@@ -238,7 +236,7 @@ int Rarefact::getSharedCurve(float percentFreq = 0.01, int nIters = 1000){
         }
         
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<sharedRarefactData*> data;
         
         //Lauch worker threads
@@ -247,18 +245,18 @@ int Rarefact::getSharedCurve(float percentFreq = 0.01, int nIters = 1000){
             //make copy of lookup so we don't get access violations
             vector<SharedRAbundVector*> copyLookup = lookup->getSharedRAbundVectors();
             label = copyLookup[0]->getLabel();
-            sharedRarefactData* dataBundle = new sharedRarefactData(lines[i+1], util, copyLookup,  displays, label, numGroupComb);
+            sharedRarefactData* dataBundle = new sharedRarefactData(lines[i+1], util, copyLookup,  displays, label, jumble);
             
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(sharedDriver, dataBundle));
+            workerThreads.push_back(new std::thread(sharedDriver, dataBundle));
         }
         
         //make copy of lookup so we don't get access violations
         vector<SharedRAbundVector*> copyLookup = lookup->getSharedRAbundVectors();
         label = copyLookup[0]->getLabel();
 
-        sharedRarefactData* dataBundle = new sharedRarefactData(lines[0], util, copyLookup,  displays, label, numGroupComb);
+        sharedRarefactData* dataBundle = new sharedRarefactData(lines[0], util, copyLookup,  displays, label, jumble);
         sharedDriver(dataBundle);
         
         for (int i = 0; i < processors-1; i++) {
