@@ -16,11 +16,11 @@ public:
 	void registerDisplay(Display* o)            {	displays.insert(o);				}
     void registerDisplays(vector<Display*> o)	{	for(int i=0;i<o.size();i++){ registerDisplay(o[i]); 	} }
     
-	void updateRankData(SAbundVector* rv)       {	rank = rv; for(set<Display*>::iterator pos=displays.begin();pos!=displays.end();pos++){ (*pos)->update(rank); } 	}
+	void updateRankData(SAbundVector& rv)       {	rank = rv; for(set<Display*>::iterator pos=displays.begin();pos!=displays.end();pos++){ (*pos)->update(rank); } 	}
 
 private:
 	set<Display*> displays;
-	SAbundVector* rank;
+	SAbundVector rank;
 	
 };
 
@@ -29,23 +29,21 @@ private:
 class SharedRarefactionCurveData : public Observable {
 	
 public:
-	SharedRarefactionCurveData() {}; //: shared1(0), shared2(0) 
+	SharedRarefactionCurveData() = default;; //: shared1(0), shared2(0) 
 	
 	void registerDisplay(Display* o)            {	displays.insert(o);				}
     void registerDisplays(vector<Display*> o)	{	for(int i=0;i<o.size();i++){ registerDisplay(o[i]); 	} }
 	
-	void updateSharedData(vector<SharedRAbundVector*> r, int numSeqs, int numGroupComb)	{
-        shared = r; NumSeqs = numSeqs; NumGroupComb = numGroupComb;
-        groups.clear(); for (int i = 0; i < r.size(); i++) { groups.push_back(r[i]->getGroup()); }
+	void updateSharedData(vector<SharedRAbundVector*> r, int numSeqs)	{
+        shared = r; NumSeqs = numSeqs; 
         
-        for(set<Display*>::iterator pos=displays.begin();pos!=displays.end();pos++){ (*pos)->update(shared, NumSeqs, NumGroupComb, groups); }
+        for(set<Display*>::iterator pos=displays.begin();pos!=displays.end();pos++){ (*pos)->update(shared, NumSeqs); }
     }
 	
 private:
 	set<Display*> displays;
 	vector<SharedRAbundVector*> shared;
 	int NumSeqs, NumGroupComb;
-    vector<string> groups;
     
 };
 
