@@ -31,7 +31,7 @@ class Utils {
 public:
     
     Utils(); 
-    ~Utils() {}
+    ~Utils() = default;
     
     //random operations
     int getRandomIndex(int); //highest
@@ -47,7 +47,7 @@ public:
     void mothurRandomShuffle(vector<long long>&);
     void mothurRandomShuffle(vector< vector<double> >&);
     void mothurRandomShuffle(vector<string>&);
-    void mothurRandomShuffle(vector<item>&);
+    void mothurRandomShuffle(vector<intPair>&);
     void mothurRandomShuffle(vector<PCell*>&);
     void mothurRandomShuffle(vector<PDistCellMin>&);
     void mothurRandomShuffle(vector<colDist>&);
@@ -74,21 +74,23 @@ public:
     void getCurrentDate(string& thisYear, string& thisMonth, string& thisDay);
     
     //file operations
-    bool mothurInitialPrep(string& defaultPath, string& tools, string& mothurVersion, string& releaseDate, string& OS);
+    bool mothurInitialPrep(vector<string>& defaultPath, vector<string>& tools, string& mothurVersion, string& releaseDate, string& OS);
     bool anyLabelsToProcess(string, set<string>&, string);
     bool appendBinaryFiles(string, string);
-    int appendFiles(string, string);
+    int appendFiles(string first, string second); //first is appending to the end of second. 
     void appendFiles(string, ofstream&);
     int appendFilesFront(string, string);
     int appendFilesWithoutHeaders(string, string);
     vector<bool> allGZFiles(vector<string>&);
     bool appendSFFFiles(string, string);
-    bool findTool(string& toolName, string&, string mothurProgramPath, vector<string>&, vector<string> locations);
-    bool findBlastLocation(string& toolLocation, string mothurProgramPath, vector<string> locations);
-    bool checkLocations(string&, vector<string>, string silent);
-    bool checkLocations(string&, vector<string>);  //filename, inputDir, outputDir. checks for file in ./, inputdir, outputdir, default and mothur's exe location, and tools location.  Returns false if cant be found. If found completes name with location
-    bool dirCheck(string&); //completes path, appends appropriate / or \, makes sure dir is writable.
-    bool dirCheck(string&, string); //completes path, appends appropriate / or \, makes sure dir is writable. - no error
+    bool findTool(string& toolName, string&, vector<string>&, vector< vector<string> > locations);
+    bool checkSpecificLocations(string&, vector<string>, string silent);
+    bool checkLocations(string&, vector< vector<string> >, string silent);
+    bool checkLocations(string&, vector< vector<string> >);  //filename, locations to check.  Returns false if cant be found. If found completes name with location
+    bool checkLocationsGZ(string&, vector< vector<string> >);
+    bool dirCheckWritable(string&); //completes path, appends appropriate / or \, makes sure dir is writable.
+    bool dirCheckExists(string&);
+    bool dirCheckExists(string&, bool); //completes path, appends appropriate / or \, makes sure dir is present.
     bool fileExists(string name);
     string findProgramPath(string programName);
     string getExtension(string);
@@ -102,6 +104,7 @@ public:
     int getAlignmentLength(string);
     
     vector<bool> isGZ(string); //checks existence and format - will fail for either or both.
+    bool isHDF5(string);
     bool mkDir(string&); //completes path, appends appropriate / or \. //returns true it exits or if we can make it
     bool mothurRemove(string);
     bool openInputFile(string, ifstream&, string); //no error given
@@ -115,6 +118,7 @@ public:
 #ifdef USE_BOOST
     bool openInputFileBinary(string, ifstream&, boost::iostreams::filtering_istream&);
     bool openInputFileBinary(string, ifstream&, boost::iostreams::filtering_istream&, string);
+    bool openOutputFileBinary(string fileName, ofstream& file, ostream*& out, boost::iostreams::filtering_streambuf<boost::iostreams::output>& outBoost);
     string getline(boost::iostreams::filtering_istream& fileHandle);
 #endif
     
@@ -133,20 +137,22 @@ public:
     
     //file reads
     bool checkReleaseVersion(string, string);
+    bool isVsearchVersionValid(string, string); //check to make sure minimum version requirements are made
     string getline(ifstream&);
     string getline(istringstream&);
     void getline(ifstream&, vector<string>&);
     void getNumSeqs(ifstream&, int&);
     int getNumSeqs(ifstream&);
-    void gobble(istream&);
-    void gobble(istringstream&);
+    //void gobble(istream&);
+    //void gobble(istringstream&);
     vector<string> parseTreeFile(string filename); //returns treenames
-    set<string> readAccnos(string);
+    unordered_set<string> readAccnos(string);
     int readAccnos(string, vector<string>&);
     int readAccnos(string, vector<string>&, string);
-    void printAccnos(string, set<string>&);
+    void printAccnos(string, unordered_set<string>&);
     void printAccnos(string, vector<string>&);
     vector<consTax> readConsTax(string);
+    void readConsTax(string, vector<Taxonomy>&);
     vector<Taxonomy> readConsTax(string inputfile, PhyloTree& tree); //fills tree
     int readConsTax(string, map<int, consTax2>&);
     void readNames(string, map<string, long long>&);
@@ -202,30 +208,32 @@ public:
     bool mothurConvert(string, float&); //use for converting user inputs. Sets commandInputsConvertError to true if error occurs. Engines check this.
     bool mothurConvert(string, double&); //use for converting user inputs. Sets commandInputsConvertError to true if error occurs. Engines check this.
     bool mothurConvert(char, string&);
-    set<string> mothurConvert(vector<string>&);
+    unordered_set<string> mothurConvert(vector<string>&);
+    void mothurConvert(vector<string>&, set<string>&);
     vector<string> mothurConvert(set<string>&);
+    set<long long> mothurConvert(vector<long long>&);
+    vector<long long > mothurConvert(set<long long>&);
+    char* mothurConvert(string); //convert string to char*
 
     
     //string manipulation
     string addUnclassifieds(string tax, int maxlevel, bool probs);
     string trimTax(string tax, int trimLevel);
-    bool checkGroupName(string name);
-    int checkName(string&);
+    bool checkGroupName(string& name);
+    bool checkGroupNames(vector<string>& name);
+    void checkName(string&);
     void getCombos(vector<string>& groupComb, vector<string> userGroups, int& numComp);
     int getNumNames(string);
-    int getNumChar(string, char);
     string getSimpleLabel(string);
-    string toUpper(string);
-    string toLower(string);
     
     string getStringFromVector(vector<string>&, string); //creates string like "v[0], v[1], ... v[n]" where ', ' is string.
     string getStringFromVector(vector<int>&, string); //creates string like "v[0], v[1], ... v[n]" where ', ' is string.
     string getStringFromVector(vector<double>&, string); //creates string like "v[0], v[1], ... v[n]" where ', ' is string.
     string getStringFromSet(set<int>&, string); //creates string like "v[0], v[1], ... v[n]" where ', ' is string.
     string getStringFromSet(set<string>&, string); //creates string like "v[0], v[1], ... v[n]" where ', ' is string.
-    set<string> getSetFromList(ListVector*&, vector< vector<string> >&); 
+    unordered_set<string> getSetFromList(ListVector*&, vector< vector<string> >&);
     string getFormattedHelp(vector<string> question, vector<string> aquestion, vector<string> issue, vector<string> aissue, vector<string> howto,vector<string> ahowto);
-    string trimString(string, int); //string, number of chars to remove from end.
+    string trimStringEnd(string, int); //string, number of chars to remove from end.
     
     bool inUsersGroups(vector<string>, vector<string>); //returns true if any of the strings in first vector are in second vector
     bool inUsersGroups(vector<int>, vector< vector<int> >);
@@ -240,8 +248,10 @@ public:
     float removeConfidences(string&);
     string removeQuotes(string);
     void removeQuotes(vector<Taxon>& tax);
+    vector<string> parseTax(string tax, vector<string>& scores);
     bool stringBlank (string);
     
+    
     //file reading
     SharedRAbundVectors* getNextShared(InputData&, bool, set<string>&, set<string>&, string&, string optionalOutput = "");//input, allLines, userLabels, processedLabels, lastLabel
     SharedRAbundFloatVectors* getNextRelabund(InputData&, bool, set<string>&, set<string>&, string&);//input, allLines, userLabels, processedLabels, lastLabel
@@ -252,23 +262,20 @@ public:
     SAbundVector* getNextSAbund(InputData&, bool, set<string>&, set<string>&, string&);//input, allLines, userLabels, processedLabels, lastLabel
     OrderVector* getNextOrder(InputData&, bool, set<string>&, set<string>&, string&);//input, allLines, userLabels, processedLabels, lastLabel
 
-    
-    void splitAtComma(string&, string&);
-    void splitAtComma(string&, vector<string>&);
-    void splitAtComma(string&, vector<int>&);
     void splitAtDash(string&, set<int>&);
     void splitAtDash(string&, set<string>&);
     void splitAtDash(string&, vector<string>&);
-    void splitAtChar(string&, set<string>&, char);
-    void splitAtChar(string&, vector<string>&, char);
+    void splitAtComma(string&, string&);
+    void splitAtComma(string& s, vector<string>& container);
+    void splitAtComma(string& s, vector<int>& container);
+    void splitAtChar(string& s, set<string>& container, char delim);
+    void splitAtChar(string& s, vector<string>& container, char delim);
     void splitAtChar(string&, string&, char);
     void splitAtEquals(string&, string&);
     vector<string> splitWhiteSpaceWithQuotes(string);
-    int splitWhiteSpaceWithQuotes(string, vector<string>&);
     vector<string> splitWhiteSpace(string& rest, char[], int);
     vector<string> splitWhiteSpace(string);
     int splitWhiteSpace(string, vector<float>&, int);
-    string trimWhiteSpace(string input);
     
     int getOTUNames(vector<string>&, int, string);
     string getTag(string); //filename
@@ -283,7 +290,7 @@ public:
 
 private:
     MothurOut* m;
-    bool modifyNames;
+    bool modifyNames, modifyGroups;
     string homePath, currentWorkingDirectory;
     mt19937_64 mersenne_twister_engine;
     vector<string> paths; //paths stored in environment varaibale PATH
