@@ -25,7 +25,7 @@ ValidParameters::ValidParameters() {
 }
 /***********************************************************************/
 
-ValidParameters::~ValidParameters() {}
+ValidParameters::~ValidParameters() = default;
 
 /***********************************************************************/
 bool ValidParameters::isValidParameter(string parameter, vector<string> cParams, string value) {
@@ -201,7 +201,9 @@ string ValidParameters::valid(map<string, string>& container, string parameter)
         map<string, string>::iterator it;
         
         it = container.find(parameter);
-        if(it != container.end()){ }
+        if(it != container.end()){
+            Utils util; it->second = util.getSimpleName(it->second); //remove path from non file options
+        }
         else { return "not found"; }
         
         return it->second;
@@ -212,6 +214,22 @@ string ValidParameters::valid(map<string, string>& container, string parameter)
     }
 }
 /******************************************************/
+string ValidParameters::validPath(map<string, string>& container, string parameter) {
+    try {
+        map<string, string>::iterator it;
+        
+        it = container.find(parameter);
+        if(it != container.end()){}
+        else { return "not found"; }
+        
+        return it->second;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "ValidParameters", "validPath");
+        exit(1);
+    }
+}
+/******************************************************/
 vector<string> ValidParameters::validFiles(map<string, string>& container, string parameter) {
     try {
         vector<string> vFiles;
@@ -276,7 +294,7 @@ string ValidParameters::validFile(map<string, string>& container, string paramet
                 it->second = util.removeQuotes(it->second);
                 string filename = it->second;
                 if (util.checkLocations(filename, current->getLocations())) { container[parameter] = filename; ableToOpen = true; }
-                else { m->mothurOut("Unable to open " + container[parameter]); m->mothurOutEndLine(); return "not open";  }
+                else { m->mothurOut("Unable to open " + container[parameter] + "\n"); return "not open";  }
                 
                 //check phylip file to make sure its really phylip and not column
                 if ((it->first == "phylip") && (ableToOpen)) {
@@ -292,8 +310,10 @@ string ValidParameters::validFile(map<string, string>& container, string paramet
                 
                 //check for blank file
                 if (ableToOpen) {
-                    if (util.isBlank(container[parameter])) {
-                        m->mothurOut("[ERROR]: " + container[parameter] + " is blank, aborting.\n");  return "not found";
+                    if (parameter != "accnos") { //ignore blank accnos
+                        if (util.isBlank(container[parameter])) {
+                            m->mothurOut("[ERROR]: " + container[parameter] + " is blank, aborting.\n");  return "not found";
+                        }
                     }
                 }
             }
